#Script prepared by Alessio Mortelliti, Allison M. Brehm and Bryn Evans and and to analyze data for the paper "LUmbrella effect in the monitoring protocols for mammals in the Northeast US.".
#Please contact Alessio Mortelliti alessio.mortelliti@maine.edu if you have any questions or concerns or if you would like to use the data associated with this paper
#The following script performs the occupancy analyses (multiple season occupancy models) and calculates the required sampling effort for a given management objective. 

#library(lme4)
library(unmarked)
library(AICcmodavg)

coyote <- read.csv(file = "Canid_coyote_multi_year_presence_by_station.csv", header=TRUE)

sites<-read.table(file="covariates.txt",header=TRUE)
################################################
########### COYOTE (Canis latrans) #############
################################################

# open detection history file
BTc <- coyote
colnames(BTc)[1] <- "site"
colnames(sites)[1] <- "site"
BTmc <- data.frame(merge(sites, BTc, by = 'site'))
BTc1 <- BTmc[, 29:259] 

days <- seq(1:33)
daysc <- matrix(days, nrow(BTc1), 231, byrow = T)  # 231 = 4 summers + 3 winters
season <- seq()
season <- as.character(c('summer','winter','summer','winter','summer','winter','summer'))
seasonc <- matrix(season, nrow(BTc1), 7, byrow = TRUE)


umfc <- unmarkedMultFrame(y = BTc1, siteCovs = sites, numPrimary = 7, yearlySiteCovs = list(season = seasonc), obsCovs = list(days = daysc))


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
#####        Selection for p (detection probability)      #####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

fmp0 <- colext(~1, ~1, ~1, ~1, umfc)
fmp1 <- colext(~1, ~1, ~1, ~days, umfc)
fmp2 <- colext(~1, ~1, ~1, ~I(days^2), umfc)
fmp3 <- colext(~1, ~1, ~1, ~log(days), umfc)
fmp4 <- colext(~1, ~1, ~1, ~factor(season), umfc)
fmp5 <- colext(~1, ~1, ~1, ~Dist_300m, umfc)
fmp6 <- colext(~1, ~1, ~1, ~Dist_1k, umfc)
fmp7 <- colext(~1, ~1, ~1, ~Dist_3k, umfc)
fmp8 <- colext(~1, ~1, ~1, ~Dist_6k, umfc)

fmp10 <- colext(~1, ~1, ~1, ~LAT, umfc)
fmp12 <- colext(~1, ~1, ~1, ~Prop_Hard_300, umfc)       
fmp13 <- colext(~1, ~1, ~1, ~Prop_Hard_1k, umfc)
fmp14 <- colext(~1, ~1, ~1, ~LAT+Dist_300m, umfc)

modelsP <- fitList(
  'psi(.)gam(.)eps(.)p(.)' = fmp0,
  'psi(.)gam(.)eps(.)p(d)' = fmp1,
  'psi(.)gam(.)eps(.)p(d^2)' = fmp2,
  'psi(.)gam(.)eps(.)p(logd)' = fmp3,
  'psi(.)gam(.)eps(.)p(season)' = fmp4,
  'psi(.)gam(.)eps(.)p(Dist_300m)' = fmp5, 
  'psi(.)gam(.)eps(.)p(Dist_1k)' = fmp6,
  'psi(.)gam(.)eps(.)p(Dist_3k)' = fmp7,
  'psi(.)gam(.)eps(.)p(Dist_6k)' = fmp8,

  'psi(.)gam(.)eps(.)p(Lat)' = fmp10,
 
  'psi(.)gam(.)eps(.)p(Prop_Hard_300)' = fmp12,
  'psi(.)gam(.)eps(.)p(Prop_Hard_1k)' = fmp13,
  'psi(.)gam(.)eps(.)p(LAT+Dist_300)' = fmp14
  )

msP <- modSel(modelsP)
print(msP)


##### # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # ####
####   Selection for psi (Prob occupancy during the FIRST season)   ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

fmps0 <- colext(~1, ~1, ~1, ~LAT, umfc) 
fmps1 <- colext(~Dist_300m, ~1, ~1, ~LAT, umfc)                                                               
fmps2 <- colext(~Dist_1k, ~1, ~1, ~LAT, umfc)                                                                             
fmps3 <- colext(~Dist_3k, ~1, ~1, ~LAT, umfc)                                                                             
fmps4 <- colext(~Dist_6k, ~1, ~1, ~LAT, umfc)                                                                             
fmps5 <- colext(~Prop_Hard_300, ~1, ~1, ~LAT, umfc)                                                                         
fmps6 <- colext(~Prop_Hard_1k, ~1, ~1, ~LAT, umfc)  
fmps7 <- colext(~LAT, ~1, ~1, ~LAT, umfc) 
  
modelsPs <- fitList(
  'psi(.)gam(.)eps(.)p(Lat)' = fmps0,
  'psi(Dist_300m)gam(.)eps(.)p(Lat)' = fmps1,
  'psi(Dist_1k)gam(.)eps(.)p(Lat)' = fmps2,
  'psi(Dist_3k)gam(.)eps(.)p(Lat)' = fmps3,
  'psi(Dist_6k)gam(.)eps(.)p(Lat)' = fmps4,
  'psi(Prop_Hard_300)gam(.)eps(.)p(Lat)' = fmps5,
  'psi(Prop_Hard_1k)gam(.)eps(.)p(Lat)' = fmps6,
  'psi(Lat)gam(.)eps(.)p(Lat)' = fmps7)

msPs <- modSel(modelsPs)
print(msPs)


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
####      Selection for Gamma (Prob colonization during study)     ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

fmg0 <- colext(~Dist_3k, ~1, ~1, ~LAT, umfc) 
fmg1 <- colext(~Dist_3k, ~Dist_300m, ~1, ~LAT, umfc)                                                               
fmg2 <- colext(~Dist_3k, ~Dist_1k, ~1, ~LAT, umfc)                                                                             
fmg3 <- colext(~Dist_3k, ~Dist_3k, ~1, ~LAT, umfc)                                                                             
fmg4 <- colext(~Dist_3k, ~Dist_6k, ~1, ~LAT, umfc)                                                                             
fmg5 <- colext(~Dist_3k, ~Prop_Hard_300, ~1, ~LAT, umfc)                                                                         
fmg6 <- colext(~Dist_3k, ~Prop_Hard_1k, ~1, ~LAT, umfc)  
fmg7 <- colext(~Dist_3k, ~LAT, ~1, ~LAT, umfc)                                                                            

modelsG <- fitList(
  'psi(Dist_3k)gam(.)eps(.)p(LAT)' = fmg0,
  'psi(Dist_3k)gam(Dist_300m)eps(.)p(Lat)' = fmg1,
  'psi(Dist_3k)gam(Dist_1k)eps(.)p(Lat)' = fmg2,
  'psi(Dist_3k)gam(Dist_3k)eps(.)p(Lat)' = fmg3,
  'psi(Dist_3k)gam(Dist_6k)eps(.)p(Lat)' = fmg4,
  'psi(Dist_3k)gam(Prop_Hard_300)eps(.)p(Lat)' = fmg5,
  'psi(Dist_3k)gam(Prop_Hard_1k)eps(.)p(Lat)' = fmg6,
  'psi(Dist_3k)gam(Lat)eps(.)p(Lat)' = fmg7)

msG <- modSel(modelsG)
print(msG)

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
####      Selection for Epsilon (Extinction probability)         ####
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

null <- colext(~1, ~1, ~1, ~1, umfc)
fme0 <- colext(~Dist_3k, ~LAT, ~1, ~LAT, umfc)
fme1 <- colext(~Dist_3k, ~LAT, ~Dist_300m, ~LAT, umfc)
fme2 <- colext(~Dist_3k, ~LAT, ~Dist_1k, ~LAT, umfc)
fme3 <- colext(~Dist_3k, ~LAT, ~Dist_3k, ~LAT, umfc)
fme4 <- colext(~Dist_3k, ~LAT, ~Dist_6k, ~LAT, umfc)
fme5 <- colext(~Dist_3k, ~LAT, ~Prop_Hard_300, ~LAT, umfc)
fme6 <- colext(~Dist_3k, ~LAT, ~Prop_Hard_1k, ~LAT, umfc)
fme7 <- colext(~Dist_3k, ~LAT, ~LAT, ~LAT, umfc)

modelsE <- fitList(
  'Null' = null,
  'psi(Dist_3k)gam(LAT)eps(.)p(Lat)' = fme0,
  'psi(Dist_3k)gam(LAT)eps(Dist_300m)p(Lat)' = fme1,
  'psi(Dist_3k)gam(LAT)eps(Dist_1k)p(Lat)' = fme2,
  'psi(Dist_3k)gam(LAT)eps(Dist_3k)p(Lat)' = fme3,
  'psi(Dist_3k)gam(LAT)eps(Dist_6k)p(Lat)' = fme4,
  'psi(Dist_3k)gam(LAT)eps(Prop_Hard_300)p(Lat)' = fme5,
  'psi(Dist_3k)gam(LAT)eps(Prop_Hard_1k)p(Lat)' = fme6,
  'psi(Dist_3k)gam(LAT)eps(Lat)p(Lat)' = fme7)
msE <- modSel(modelsE, nullmod="Null")
print(msE)



ms2 <- as(msE, "data.frame")
write.csv(ms2, file="Coyote_OUTPUTS.csv") 
############### FIGURE ##################

tiff(file = "Coyote.tiff", width = 2800, height = 1800, compression = 'lzw',  units = "px", res = 300)     


op <- par(mfrow=c(2,2), mar=c(5, 4, 4, 2) + 0.1)

LAT = seq(min(sites$LAT), max(sites$LAT), length=16)

nd <- data.frame(cbind(LAT))


############### DETECTION
E.col <- predict(fme7, type="det", newdata = nd , appendData = FALSE)
G <- nd$LAT[1:16]
Gcol <- E.col$Predicted[1:16]
Gcolu <- E.col$lower[1:16]
Gcold <- E.col$upper[1:16]
plot(G, Gcol, xlim = c(min(sites$LAT), max(sites$LAT)), axes = F, ylim = c(0, 0.4), type = "l", lwd = 3, frame = F, xlab = "Latitude",
     ylab = "Detection probability", cex.lab = 1.2, cex.axis = 1)
axis(1, at=c(44.15,45.27,46.34, 47.42))
axis(2, at=c(0, 0.2, 0.4, 0.8, 1) ) # labels = c("1", "6", "11", "16")
polygon(c(rev(G), G), c(rev(Gcolu), Gcold), col = rgb(0.5, 0.5, 0.5, 0.5), border = NA)
# lines(G, Gcolu, lwd = 2, col="black", lty = 'dashed')


############# PSI

Dist_3k = seq(min(sites$Dist_3k), max(sites$Dist_3k), length=16)
nd <- data.frame(cbind(LAT,Dist_3k))



E.col <- predict(fme7, type="psi", newdata = nd, appendData = FALSE)
G <- nd$Dist_3k[1:16]
Gcol <- E.col$Predicted[1:16]
Gcolu <- E.col$lower[1:16]
Gcold <- E.col$upper[1:16]
plot(G, Gcol, xlim = c(min(sites$Dist_3k), max(sites$Dist_3k)), axes = F, ylim = c(0,1), type = "l", lwd = 3, frame = F,
     xlab = "Disturbance (3km)",
     ylab = "Presence probability", cex.lab = 1.2, cex.axis = 1)
axis(1, at = c(1.26,2.72,4.19,5.66))
axis(2, at = c(0, 0.2, 0.4, 0.8, 1) ) # labels = c("1","6","11","16")
polygon(c(rev(G), G), c(rev(Gcolu), Gcold), col = rgb(0.5, 0.5, 0.5, 0.5), border = NA)


############### COLONIZATION

nd <- data.frame(cbind(LAT))

E.col <- predict(fme7, type = "col", newdata = nd, appendData = FALSE)
G <- nd$LAT[1:16]
Gcol <- E.col$Predicted[1:16]
Gcolu <- E.col$lower[1:16]
Gcold <- E.col$upper[1:16]
plot(G, Gcol, xlim = c(min(sites$LAT), max(sites$LAT)), axes = F, ylim = c(0, 1), type = "l", lwd = 3, frame = F, xlab = "Latitude",
     ylab = "Colonization probability", cex.lab = 1.2, cex.axis = 1)
axis(1, at = c(44.15,45.27,46.34, 47.42))
axis(2, at = c(0, 0.2, 0.4, 0.8, 1) ) # labels = c("1","6","11","16")
polygon(c(rev(G), G), c(rev(Gcolu), Gcold), col = rgb(0.5, 0.5, 0.5, 0.5), border = NA)




############ EXTINCTION
E.col <- predict(fme7, type = "ext", newdata = nd, appendData = FALSE)
G <- nd$LAT[1:16]
Gcol <- E.col$Predicted[1:16]
Gcolu <- E.col$lower[1:16]
Gcold <- E.col$upper[1:16]
plot(G, Gcol, xlim = c(min(sites$LAT), max(sites$LAT)), axes = F, ylim = c(0, 1), type = "l", lwd = 3, frame = F,  xlab = "Latitude",
     ylab = "Extinction probability", cex.lab = 1.2, cex.axis = 1)
axis(1, at = c(44.15,45.27,46.34, 47.42))
axis(2, at = c(0, 0.2, 0.4, 0.8, 1) ) # labels = c("1","6","11","16")
polygon(c(rev(G), G), c(rev(Gcolu), Gcold), col = rgb(0.5, 0.5, 0.5, 0.5), border = NA)


title(outer = T, adj = 0.5, main = list("Coyote", cex = 1.3, col = "black", 
                                  font = 1), line = -2)      

dev.off()









simhist <- function(S,K,psi,p){
  h <- matrix(NA,S,K)
  z <- rbinom(S,1,psi)
  for (ii in 1:S){
    h[ii,] <- rbinom(K,1,p*z[ii])
  }
  return(h)
}

## Log-likelihood function for the occupancy model
loglik <- function(param, h){
  s <- dim(h)[1] # nr sites
  k <- dim(h)[2] # nr sampling occasions
  psi <- 1/(1+exp(-param[1]))  # to probabilities
  p <- 1/(1+exp(-param[2]))
  d <- sum(sum(h)) # summary statistics
  Sd <- sum(rowSums(h)>0)
  loglik <- -(Sd*log(psi)+d*log(p)+(k*Sd-d)*log(1-p)+(s-Sd)*log((1-psi)+psi*(1-p)^k))
  return(loglik)
}

## Analyze two datasets with different psi and different p  
fitmA <-function(h1,h2){
  fm1 <- optim(par=runif(2), fn=loglik, h=h1, hessian=T)
  fm2 <- optim(par=runif(2), fn=loglik, h=h2, hessian=T)
  VC1 <- try(solve(fm1$hessian),silent = TRUE)
  VC2 <- try(solve(fm2$hessian),silent = TRUE)  
  pars <- 1/(1+exp(-c(fm1$par,fm2$par)))    # to probabilities
  if ((class(VC1)=="try-error")||(class(VC2)=="try-error")){
    SEs <- rep(NA,4)
  }else{
    SEs <- c(sqrt(diag(VC1))*pars[1:2]*(1-pars[1:2]),sqrt(diag(VC2))*pars[3:4]*(1-pars[3:4]))
  }
  psi1 <- list(est = pars[1], se = SEs[1]) # arrange output
  p1 <- list(est = pars[2], se = SEs[2])
  psi2 <- list(est = pars[3], se = SEs[3])
  p2 <- list(est = pars[4], se = SEs[4])
  myres <- list(psi1 = psi1, p1 = p1, psi2 = psi2, p2 = p2,L = fm1$value + fm2$value)	
  return(myres)
}

## Run one simulation and do Wald test on probability scale
run1PAsim <- function(S1,S2,K1,K2,p1,p2,psi1,R,alpha){
  # simulate detection histories
  h1<-simhist(S=S1,K=K1,psi=psi1,p=p1)
  h2<-simhist(S=S2,K=K2,psi=psi1*(1-R),p=p2)
  # fit model
  fmA <-fitmA(h1,h2)
  # test for significance	
  Wald <- abs(fmA$psi1$est - fmA$psi2$est )/sqrt(fmA$psi1$se^2 + fmA$psi2$se^2)>qnorm(1-alpha/2)
  return(Wald)
}

## Run power analysis simulations 
runPowerSims <- function(S1,S2,K1,K2,p1,p2,psi1,R,alpha,nsims){
  powcnt <- 0
  okcnt <- 0
  t1 <- proc.time()
  for (ii in 1:nsims){
    cat('\r',ii); flush.console()
    res <- run1PAsim(S1=S1,S2=S2,K1=K1,K2=K2,p1=p1,p2=p2,psi1=psi1,R=R,alpha=alpha)
    if (is.finite(res)){
	    powcnt <- powcnt + res
	    okcnt <- okcnt + 1
    }
  }
  power <- powcnt/okcnt
  tdiff <- proc.time()-t1
  cat("\r","power (Wald test) = ", power[1],"\n")
  if (okcnt!=nsims){ 
	cat(nsims-okcnt, "simulations discarded (due to failed VC calculation)","\n")
  }  
  cat("elapsed time = ", tdiff[3] , " seconds\n\n\n") 
  return(c(power,okcnt))
}

## Calculate the power of a design using the formula in ms
calcPowerFormula <- function(S1,S2,K1,K2,p1,p2,psi1,R,alpha){
  psi2 <- psi1*(1-R)
  pp1 <- 1-(1-p1)^K1
  pp2 <- 1-(1-p2)^K2
  F1 <- (1-pp1)/(pp1-K1*p1*(1-p1)^(K1-1))
  F2 <- (1-pp2)/(pp2-K2*p2*(1-p2)^(K2-1))
  var1 <- psi1*(1-psi1+F1)/S1
  var2 <- psi2*(1-psi2+F2)/S2
  limL <- (+qnorm(1-alpha/2)*(sqrt(var1+var2))-(psi1-psi2))/sqrt(var1+var2)
  limU <- (-qnorm(1-alpha/2)*(sqrt(var1+var2))-(psi1-psi2))/sqrt(var1+var2)
  G <- 1 - pnorm(limL) + pnorm(limU)
  return(G)
}

## Determine the required sample size using the formula in ms
calcSFormula <- function(K1,K2,p1,p2,psi1,R,alpha,pow){
  psi2 <- psi1*(1-R)
  pp1 <- 1-(1-p1)^K1
  pp2 <- 1-(1-p2)^K2
  F1 <- (1-pp1)/(pp1-K1*p1*(1-p1)^(K1-1))
  F2 <- (1-pp2)/(pp2-K2*p2*(1-p2)^(K2-1))
  f1 <- psi1*(1-psi1+F1)
  f2 <- psi2*(1-psi2+F2)
  S <- (f1+f2)*((qnorm(1-alpha/2)+qnorm(pow))/(psi1-psi2))^2
  return(ceiling(S))
}


# loading the packages
library(raster)
library(rgeos)
library(rgdal)

# loading the shapefile
disturbshp<-readOGR("C://Users//alessio.mortelliti//Documents//ArcGIS//TownshipMARTEN//Township_Dissolve_Any_Survey_Effort_Shapefile.shp")


 plot(disturbshp) 
summary(disturbshp)

# to see the table
head(disturbshp@data)
disturbshp
colnames(disturbshp@data) <- c("TOWN",  "COUNTY","Dist_300m", "Dist_1k","Dist_3k","Dist_6k","Prop_Hard_300","Prop_Hard_1k","LAT","LONG")
disturbshp$psiconst<-1
mypallete<-colorRampPalette(c("lightpink","yellow","orange","green"))

#Extract coefficients
cf<-as.data.frame(coef(fme7))
#predict psi, col,gam and p
psi<-exp(cf[1,1]+ cf[2,1]*disturbshp$Dist_3k)/(1+exp(cf[1,1]+ cf[2,1]*disturbshp$Dist_3k))
col<- exp(cf[3,1] + cf[4,1]*(disturbshp$LAT))/(1+exp(cf[3,1] + cf[4,1]*(disturbshp$LAT)))
ext<-exp(cf[5,1]+cf[6,1]*(disturbshp$LAT) )/(1+exp(cf[5,1]+cf[6,1]*(disturbshp$LAT) ))
det<-exp( cf[7,1] + cf[8,1]*disturbshp$LAT)/(1+exp( cf[7,1] + cf[8,1]*disturbshp$LAT))                    

#calculate psi for each of 4 years
psi2<- psi*ext+   (1-ext)*col
psi3<- psi2*ext+   (1-ext)*col
psi4<- psi3*ext+   (1-ext)*col

disturbshp$psiavg<-(psi+psi2+psi3+psi4)/4
head(disturbshp@data)

#calculating p* (i.e. cumulative detection probability) - which is the probability of detecting the species at least once during x days
px<- 1-(1-det)^21
min(px)
mean(px)
hist(px)



####
K <- 21		# number of days
R <-0.5	# proportional change in occupancy    R>0 represents a decline and R < 0 an increase. 
psi1 <- disturbshp$psiavg       # initial occupancy probability
p <- det		# detection probability
alpha <-0.05	# significance level
pow <- 0.8		# target power level
SS <- (calcSFormula(K1=K,K2=K,p1=p,p2=p,psi1,R,alpha,pow))/21
disturbshp$Sample50 <-SS
hist(disturbshp$Sample50)

colors<-mypallete(5)[cut(disturbshp$Sample50,5)] 
plot(disturbshp,col=colors) 

####25% decline

 K <- 21		# number of days
R <- 0.25	# proportional change in occupancy    R>0 represents a decline and R < 0 an increase. 
psi1 <- disturbshp$psiavg       # initial occupancy probability
p <- det		# detection probability
alpha <-0.05	# significance level
pow <- 0.8		# target power level
SS <- (calcSFormula(K1=K,K2=K,p1=p,p2=p,psi1,R,alpha,pow))/21
disturbshp$Sample25 <-SS
hist(disturbshp$Sample25)

colors<-mypallete(5)[cut(disturbshp$Sample25,5)] 
plot(disturbshp,col=colors) 

####10% decline

K <- 21		# number of days
R <- 0.1	# proportional change in occupancy   
#psi1 <- disturbshp$psiavg       # initial occupancy probability
p <- det		# detection probability
alpha <-0.05	# significance level
pow <- 0.8		# target power level
SS <- (calcSFormula(K1=K,K2=K,p1=p,p2=p,psi1,R,alpha,pow))/21
disturbshp$Sample10 <-SS
hist(disturbshp$Sample10)

colors<-mypallete(5)[cut(disturbshp$Sample10,5)] 
# plot
plot(disturbshp,col=colors) 

proj4string(disturbshp)<-"+proj=utm +zone=19 +datum=NAD83 +units=m +no_defs +ellps=GRS80 +towgs84=0,0,0"
writeOGR(disturbshp,dsn=("C://Users//alessio.mortelliti//Documents//ArcGIS"),layer="Sampling_protocol_coyote",driver="ESRI Shapefile")

