#Script prepared by Alessio Mortelliti, Allison M. Brehm and Bryn Evans and and to analyze data for the paper "LUmbrella effect in the monitoring protocols for mammals in the Northeast US.".
#Please contact Alessio Mortelliti alessio.mortelliti@maine.edu if you have any questions or concerns or if you would like to use the data associated with this paper
#The following script performs the occupancy analyses (multiple season occupancy models) and calculates the required sampling effort for a given management objective. 

library(unmarked)
library(AICcmodavg)

mart<-read.table(file="fisher197maine_ALLYEARS.txt",header=TRUE)
sites<-read.table(file="covariates.txt",header=TRUE)
cor(sites[3:28],sites[3:28] )
BT<-mart
colnames(BT)[1] <- "site"
colnames(sites)[1] <- "site"
BTm<-data.frame(merge(sites,BT, by='site'))
BT1<-BTm[,29:259]
 

days<-seq(1:33)
days2 <- matrix(days, nrow(BT1), 231, byrow=T)                   
season<-seq()
season <- as.character(c('summer','winter','summer','winter','summer','winter','summer'))
season2 <- matrix(season, nrow(BT1), 7, byrow=TRUE)


umf <- unmarkedMultFrame(y = BT1,siteCovs = sites, numPrimary = 7,yearlySiteCovs=list(season=season2),obsCovs=list(days=days2))

  ####################################
   #######selection for p (detection probability) ######
   ######################################

######################################
fm0 <- colext(~1, ~1, ~1, ~1,starts=c(-1,-1,-1, -1), umf)
fm01 <- colext(~1, ~1, ~1, ~days, umf)
fm02 <- colext(~1, ~1, ~1, ~I(days^2), umf)
fm03 <- colext(~1, ~1, ~1, ~log(days), umf)
fm04 <- colext(~1, ~1, ~1, ~factor(season), umf)
fm05 <- colext(~1, ~1, ~1, ~Dist_300m, umf)
fm06 <- colext(~1, ~1, ~1, ~Dist_1k, umf)
fm07 <- colext(~1, ~1, ~1, ~Dist_3k, umf)
fm08 <- colext(~1, ~1, ~1, ~Dist_6k, umf)
fm09 <- colext(~1, ~1, ~1, ~LAT, umf)
fm010 <- colext(~1, ~1, ~1, ~Prop_Hard_300, umf)
fm011 <- colext(~1, ~1, ~1, ~Prop_Hard_1k, umf)
fm013 <- colext(~1, ~1, ~1, ~Dist_6k+season, umf)
fm014 <- colext(~1, ~1, ~1, ~Dist_6k+season+Prop_Hard_1k, umf)


models <- fitList('psi(.)gam(.)eps(.)p(.)' = fm0,
'psi(.)gam(.)eps(.)p(d)' = fm01,
'psi(.)gam(.)eps(.)p(d^2)' = fm02,
'psi(.)gam(.)eps(.)p(logd)' = fm03,
'psi(.)gam(.)eps(.)p(season)' = fm04,
'psi(.)gam(.)eps(.)p(Disturbance_300m)' = fm05, 
'psi(.)gam(.)eps(.)p(Dist_1k)' = fm06,
'psi(.)gam(.)eps(.)p(Dist_3k)' = fm07,
'psi(.)gam(.)eps(.)p(Dist_6k)' = fm08,
'psi(.)gam(.)eps(.)p(LAT)' = fm09,
'psi(.)gam(.)eps(.)p(Prop_Hard_300)'= fm010,
'psi(.)gam(.)eps(.)p(Prop_Hard_1k)'= fm011,
'psi(.)gam(.)eps(.)p(Dist_6k+season))'= fm013,
'psi(.)gam(.)eps(.)p(Dist_6k+season+Prop_Hard_1k))'= fm014)

ms <- modSel(models)
print(ms)


  ####################################
   #######selection for PSI #######################
fm2 <- colext(~Dist_300m, ~1, ~1, ~Dist_6k+season+Prop_Hard_1k, umf)                                                                  
fm3 <- colext(~Dist_1k, ~1, ~1, ~Dist_6k+season+Prop_Hard_1k, umf)
fm4 <- colext(~Dist_3k, ~1, ~1, ~Dist_6k+season+Prop_Hard_1k, umf)                                                                    
fm5 <- colext(~Dist_6k, ~1, ~1, ~Dist_6k+season+Prop_Hard_1k, umf)  
fm6 <- colext(~Prop_Hard_300, ~1, ~1, ~Dist_6k+season+Prop_Hard_1k, umf)                                                           
fm7 <- colext(~Prop_Hard_1k , ~1, ~1, ~Dist_6k+season+Prop_Hard_1k, umf)                                                            
fm8 <- colext(~LAT, ~1, ~1, ~Dist_6k+season+Prop_Hard_1k, umf)                                                             
fm9 <- colext(~1, ~1, ~1, ~Dist_6k+season+Prop_Hard_1k, umf)                                                               
fm10 <- colext(~Prop_Hard_300+Dist_3k, ~1, ~1, ~Dist_6k+season+Prop_Hard_1k, umf)           

models <- fitList(
'psi(Dist_300m)gam(.)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm2,
'psi(Dist_1k)gam(.)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm3,
'psi(Dist_3k)gam(.)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm4,
'psi(Dist_6k)gam(.)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm5,
'psi(Prop_Hard_300)gam(.)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm6,
'psi(Prop_Hard_1k)gam(.)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm7,
'psi(LAT)gam(.)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm8, 
'psi(.)gam(.)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm9,
'psi(Prop_Hard_300+Dist_3k)gam(.)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm10)
ms <- modSel(models)                                       
#psi constant

####################################
  #######selection for gamma ############
fm11 <- colext(~1, ~Dist_300m,~ 1, ~Dist_6k+season+Prop_Hard_1k, umf)
fm12 <- colext(~1, ~Dist_1k,~ 1, ~Dist_6k+season+Prop_Hard_1k, umf)
fm13 <- colext(~1, ~Dist_3k,~ 1, ~Dist_6k+season+Prop_Hard_1k, umf)
fm14 <- colext(~1, ~Dist_6k,~ 1, ~Dist_6k+season+Prop_Hard_1k, umf)
fm15 <- colext(~1, ~LAT,~ 1, ~Dist_6k+season+Prop_Hard_1k, umf)
fm16 <- colext(~1, ~1,~ 1, ~Dist_6k+season+Prop_Hard_1k, umf)
fm17 <- colext(~1, ~Prop_Hard_300,~ 1, ~Dist_6k+season+Prop_Hard_1k, umf)
fm18 <- colext(~1, ~Prop_Hard_1k,~ 1, ~Dist_6k+season+Prop_Hard_1k, umf)

models <- fitList(
'psi(.)gam(Dist_300m)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm11,
'psi(.)gam(Dist_1k)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm12,
'psi(.)gam(Dist_3k)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm13,
'psi(.)gam(Dist_6k)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm14,
'psi(.)gam(LAT)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm15,
'psi(.)gam(.)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm16,
'psi(.)gam(Prop_Hard_300)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm17,
'psi(.)gam(Prop_Hard_1k)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm18)

ms <- modSel(models)
print(ms)


####################################
   #######selection for epsilon #####
fm11b <- colext(~1, ~Prop_Hard_300,~ Dist_3k, ~Dist_6k+season+Prop_Hard_1k, umf)
fm12b <- colext(~1, ~Prop_Hard_300,~Dist_1k , ~Dist_6k+season+Prop_Hard_1k, umf)
fm13b <- colext(~1, ~Prop_Hard_300,~ Dist_300m, ~Dist_6k+season+Prop_Hard_1k, umf)
fm14b <- colext(~1, ~Prop_Hard_300,~ Dist_6k, ~Dist_6k+season+Prop_Hard_1k, umf)
fm15b <- colext(~1, ~Prop_Hard_300,~LAT , ~Dist_6k+season+Prop_Hard_1k, umf)
fm16b <- colext(~1, ~Prop_Hard_300,~ 1, ~Dist_6k+season+Prop_Hard_1k, umf)
fm17b <- colext(~1, ~Prop_Hard_300,~ Prop_Hard_300, ~Dist_6k+season+Prop_Hard_1k, umf)
fm18b <- colext(~1, ~Prop_Hard_300,~ Prop_Hard_1k, ~Dist_6k+season+Prop_Hard_1k, umf)
null <- colext(~1, ~1, ~1, ~1,starts=c(-2,-2,-2, -2), umf)

models <- fitList(
'psi(.)gam(Prop_Hard_300)eps(Dist_300m.)p(Dist_6k+season+Prop_Hard_1k)' = fm11b,
'psi(.)gam(Prop_Hard_300)eps(Dist_1k.)p(Dist_6k+season+Prop_Hard_1k)' = fm12b,
'psi(.)gam(Prop_Hard_300)eps(Dist_3k.)p(Dist_6k+season+Prop_Hard_1k)' = fm13b,
'psi(.)gam(Prop_Hard_300)eps(Dist_6k.)p(Dist_6k+season+Prop_Hard_1k)' = fm14b,
'psi(.)gam(Prop_Hard_300)eps(LAT.)p(Dist_6k+season+Prop_Hard_1k)' = fm15b,
'psi(.)gam(Prop_Hard_300)eps(.)p(Dist_6k+season+Prop_Hard_1k)' = fm16b, 
'psi(.)gam(Prop_Hard_300)eps(Prop_Hard_300)p(Dist_6k+season+Prop_Hard_1k)' = fm17b,
'psi(.)gam(Prop_Hard_300)eps(Prop_Hard_1k)p(Dist_6k+season+Prop_Hard_1k)' = fm18b,
 'Null' = null)          #remember to include this to obtain Nagelkerke's Rsquared'
ms <- modSel(models, nullmod="Null")

print(ms)

#below we save the outputs
ms2 <- as(ms, "data.frame")
write.csv(ms2, file="FisherOUTPUTS.csv") 
 
 ###############FIGURE##################
#######################################


   

 tiff(file = "Fisher.tiff",width = 2800, height = 1800, compression = 'lzw',  units = "px", res = 300)     #note that in the

  op <- par(mfrow=c(2,2), mar=c(5, 4, 4, 2) + 0.1)
#DETECTION
Prop_Hard_1k=seq(mean(sites$Prop_Hard_1k), mean(sites$Prop_Hard_1k), length=2)
Dist_300m=  seq(min(sites$Dist_300m), max(sites$Dist_300m), length=2)
Dist_6k= seq(mean(sites$Dist_6k), mean(sites$Dist_6k), length=2)
days=seq(1,33,length=2)
LAT=seq(min(sites$LAT), max(sites$LAT), length=2)
season=   c(rep('summer',1),rep('winter',1))
nd<-data.frame(cbind(Prop_Hard_1k,Dist_300m,Dist_6k,days,LAT,season))
nd<-data.frame(season=   c('summer','winter'),Dist_6k=mean(sites$Dist_6k),Prop_Hard_1k=mean(Prop_Hard_1k) )

###############
E.det <- predict(fm14b, type='det', newdata=nd)
 with(E.det, {
plot(1:2, Predicted, pch=16, xaxt='n', xlab='Season', font.main=1,frame=F, cex.axis = 1,     
ylab='Detection probability', cex.lab=1.2, cex.axis=1,
ylim=c(0,0.3), col=1)
axis(1, at=1:2,,labels=nd$season)
arrows(1:2, lower, 1:2, upper, code=3, angle=90, length=0.03, col=1)
})
###########

#COLONIZATION DISTURBANCE
Prop_Hard_300=seq(min(sites$Prop_Hard_300), max(sites$Prop_Hard_300), length=16)
SNOW_AVE_DAILY_MAX=seq(mean(sites$SNOW_AVE_DAILY_MAX), mean(sites$SNOW_AVE_DAILY_MAX), length=16)
Dist_300m=  seq(min(sites$Dist_300m), max(sites$Dist_300m), length=16)
Dist_3k= seq(min(sites$Dist_3k), max(sites$Dist_3k), length=16)
nd<-data.frame(cbind(Prop_Hard_300,SNOW_AVE_DAILY_MAX,Dist_300m,Dist_3k))
E.col <- predict(fm14b, type="col",newdata=nd, appendData=FALSE)
G<-nd$Prop_Hard_300[1:16]
Gcol<-E.col$Predicted[1:16]
Gcolu<-E.col$lower[1:16]
Gcold<-E.col$upper[1:16]
plot(G, Gcol,xlim=c(min(sites$Prop_Hard_300),max(sites$Prop_Hard_300)), axes=F,ylim=c(0,1), type="l", lwd=3,frame=F,                          xlab="Proportion Hardwood (300m)",
ylab="Colonization probability", cex.lab=1.2, cex.axis=1)
axis(1,at=c(0, 0.25,0.5,0.75,1))
axis(2,at=c(0,0.2,0.4,0.8,1) ) # labels=c("1","6","11","16" )

polygon(c(rev(G),G),c(rev(Gcolu),Gcold), col = rgb(0.5,0.5,0.5,0.5),  border = NA)



#EXTINCTION   -disturbance
Prop_Hard_300=seq(min(sites$Prop_Hard_300), max(sites$Prop_Hard_300), length=16)
SNOW_AVE_DAILY_MAX=seq(mean(sites$SNOW_AVE_DAILY_MAX), mean(sites$SNOW_AVE_DAILY_MAX), length=16)
Dist_300m=  seq(min(sites$Dist_300m), max(sites$Dist_300m), length=16)
Dist_6k= seq(min(sites$Dist_6k), max(sites$Dist_6k), length=16)
days=seq(1,33,length=16)
LAT=seq(min(sites$LAT), max(sites$LAT), length=16)
nd<-data.frame(cbind(Prop_Hard_300,SNOW_AVE_DAILY_MAX,Dist_300m,Dist_6k,days,LAT))

E.col <- predict(fm14b, type="ext",newdata=nd, appendData=FALSE)
G<-nd$Dist_6k[1:16]
Gcol<-E.col$Predicted[1:16]
Gcolu<-E.col$lower[1:16]
Gcold<-E.col$upper[1:16]
plot(G, Gcol,xlim=c(min(sites$Dist_6k),max(sites$Dist_6k)), axes=F,ylim=c(0,1), type="l", lwd=3,frame=F,                          xlab="Disturbance (6k)",
ylab="Extinction probability", cex.lab=1.2, cex.axis=1)
axis(1,at=c(1.45,2.79,4.14,5.49))
axis(2,at=c(0,0.2,0.4,0.8,1) ) 

polygon(c(rev(G),G),c(rev(Gcolu),Gcold), col = rgb(0.5,0.5,0.5,0.5),  border = NA)
#lines(G, Gcolu,lwd=2,col="black",lty = 'dashed')
title(outer=T,adj=0.5,main = list("Fisher", cex=1.3,col="black", 
font=1 )  , line = -2)
dev.off()




################RUN THE FUNCTIONS

simhist <- function(S,K,psi,p){
  h <- matrix(NA,S,K)
  z <- rbinom(S,1,psi)
  for (ii in 1:S){
    h[ii,] <- rbinom(K,1,p*z[ii])
  }
  return(h)
}

## Log-likelihood function for the occupancy model
loglik <- function(param, h){
  s <- dim(h)[1] # nr sites
  k <- dim(h)[2] # nr sampling occasions
  psi <- 1/(1+exp(-param[1]))  # to probabilities
  p <- 1/(1+exp(-param[2]))
  d <- sum(sum(h)) # summary statistics
  Sd <- sum(rowSums(h)>0)
  loglik <- -(Sd*log(psi)+d*log(p)+(k*Sd-d)*log(1-p)+(s-Sd)*log((1-psi)+psi*(1-p)^k))
  return(loglik)
}

## Analyze two datasets with different psi and different p  
fitmA <-function(h1,h2){
  fm1 <- optim(par=runif(2), fn=loglik, h=h1, hessian=T)
  fm2 <- optim(par=runif(2), fn=loglik, h=h2, hessian=T)
  VC1 <- try(solve(fm1$hessian),silent = TRUE)
  VC2 <- try(solve(fm2$hessian),silent = TRUE)  
  pars <- 1/(1+exp(-c(fm1$par,fm2$par)))    # to probabilities
  if ((class(VC1)=="try-error")||(class(VC2)=="try-error")){
    SEs <- rep(NA,4)
  }else{
    SEs <- c(sqrt(diag(VC1))*pars[1:2]*(1-pars[1:2]),sqrt(diag(VC2))*pars[3:4]*(1-pars[3:4]))
  }
  psi1 <- list(est = pars[1], se = SEs[1]) # arrange output
  p1 <- list(est = pars[2], se = SEs[2])
  psi2 <- list(est = pars[3], se = SEs[3])
  p2 <- list(est = pars[4], se = SEs[4])
  myres <- list(psi1 = psi1, p1 = p1, psi2 = psi2, p2 = p2,L = fm1$value + fm2$value)	
  return(myres)
}

## Run one simulation and do Wald test on probability scale
run1PAsim <- function(S1,S2,K1,K2,p1,p2,psi1,R,alpha){
  # simulate detection histories
  h1<-simhist(S=S1,K=K1,psi=psi1,p=p1)
  h2<-simhist(S=S2,K=K2,psi=psi1*(1-R),p=p2)
  # fit model
  fmA <-fitmA(h1,h2)
  # test for significance	
  Wald <- abs(fmA$psi1$est - fmA$psi2$est )/sqrt(fmA$psi1$se^2 + fmA$psi2$se^2)>qnorm(1-alpha/2)
  return(Wald)
}

## Run power analysis simulations 
runPowerSims <- function(S1,S2,K1,K2,p1,p2,psi1,R,alpha,nsims){
  powcnt <- 0
  okcnt <- 0
  t1 <- proc.time()
  for (ii in 1:nsims){
    cat('\r',ii); flush.console()
    res <- run1PAsim(S1=S1,S2=S2,K1=K1,K2=K2,p1=p1,p2=p2,psi1=psi1,R=R,alpha=alpha)
    if (is.finite(res)){
	    powcnt <- powcnt + res
	    okcnt <- okcnt + 1
    }
  }
  power <- powcnt/okcnt
  tdiff <- proc.time()-t1
  cat("\r","power (Wald test) = ", power[1],"\n")
  if (okcnt!=nsims){ 
	cat(nsims-okcnt, "simulations discarded (due to failed VC calculation)","\n")
  }  
  cat("elapsed time = ", tdiff[3] , " seconds\n\n\n") 
  return(c(power,okcnt))
}

## Calculate the power of a design using the formula in ms
calcPowerFormula <- function(S1,S2,K1,K2,p1,p2,psi1,R,alpha){
  psi2 <- psi1*(1-R)
  pp1 <- 1-(1-p1)^K1
  pp2 <- 1-(1-p2)^K2
  F1 <- (1-pp1)/(pp1-K1*p1*(1-p1)^(K1-1))
  F2 <- (1-pp2)/(pp2-K2*p2*(1-p2)^(K2-1))
  var1 <- psi1*(1-psi1+F1)/S1
  var2 <- psi2*(1-psi2+F2)/S2
  limL <- (+qnorm(1-alpha/2)*(sqrt(var1+var2))-(psi1-psi2))/sqrt(var1+var2)
  limU <- (-qnorm(1-alpha/2)*(sqrt(var1+var2))-(psi1-psi2))/sqrt(var1+var2)
  G <- 1 - pnorm(limL) + pnorm(limU)
  return(G)
}

## Determine the required sample size using the formula in ms
calcSFormula <- function(K1,K2,p1,p2,psi1,R,alpha,pow){
  psi2 <- psi1*(1-R)
  pp1 <- 1-(1-p1)^K1
  pp2 <- 1-(1-p2)^K2
  F1 <- (1-pp1)/(pp1-K1*p1*(1-p1)^(K1-1))
  F2 <- (1-pp2)/(pp2-K2*p2*(1-p2)^(K2-1))
  f1 <- psi1*(1-psi1+F1)
  f2 <- psi2*(1-psi2+F2)
  S <- (f1+f2)*((qnorm(1-alpha/2)+qnorm(pow))/(psi1-psi2))^2
  return(ceiling(S))
}



# loading the packages
library(raster)
library(rgeos)
library(rgdal)

# loading the shapefile
disturbshp<-readOGR("C://Users//alessio.mortelliti//Documents//ArcGIS//TownshipMARTEN//Township_Dissolve_Any_Survey_Effort_Shapefile.shp")


 plot(disturbshp) 
summary(disturbshp)

# to see the table
head(disturbshp@data)
disturbshp
colnames(disturbshp@data) <- c("TOWN",  "COUNTY","Dist_300m", "Dist_1k","Dist_3k","Dist_6k","Prop_Hard_300","Prop_Hard_1k","LAT","LONG")
disturbshp$psiconst<-1

mypallete<-colorRampPalette(c("lightpink","yellow","orange","green"))

#Extract coefficients
cf<-as.data.frame(coef(fm14b))
#predict psi, col,gam and p
psi<-exp(cf[1,1]*disturbshp$psiconst)/(1+exp(cf[1,1]*disturbshp$psiconst))
col<- exp(cf[2,1] + cf[3,1]*(disturbshp$Prop_Hard_300))/(1+exp(cf[2,1] + cf[3,1]*(disturbshp$Prop_Hard_300)))
ext<-exp(cf[4,1]+cf[5,1]*(disturbshp$Dist_6k) )/(1+exp(cf[4,1]+cf[5,1]*(disturbshp$Dist_6k) ))
det<-exp( cf[6,1] + cf[7,1]*disturbshp$Dist_6k+cf[8,1]*(1)+cf[9,1]*disturbshp$Prop_Hard_1k )/(1+exp( cf[6,1] + cf[7,1]*disturbshp$Dist_6k+cf[8,1]*(1)+cf[9,1]*disturbshp$Prop_Hard_1k ))                    ##  cf[8,1]*(1) cange to 0 for summer

#calculate psi for each of 4 years
psi2<- psi*ext+   (1-ext)*col
psi3<- psi2*ext+   (1-ext)*col
psi4<- psi3*ext+   (1-ext)*col

disturbshp$psiavg<-(psi+psi2+psi3+psi4)/4
head(disturbshp@data)

###################################################################

#calculating p* (i.e. cumulative detection probability) 
px<- 1-(1-det)^21
min(px)
mean(px)
hist(px)



####
K <- 21		# number of days
R <-0.5	# proportional change in occupancy    R>0 represents a decline and R < 0 an increase. 
psi1 <- disturbshp$psiavg       # initial occupancy probability
p <- det		# detection probability
alpha <-0.05	# significance level
pow <- 0.8		# target power level
SS <- (calcSFormula(K1=K,K2=K,p1=p,p2=p,psi1,R,alpha,pow))/21
disturbshp$Sample50 <-SS
hist(disturbshp$Sample50)

colors<-mypallete(5)[cut(disturbshp$Sample50,5)] 
plot(disturbshp,col=colors) 

####25% decline

 K <- 21		# number of days
R <- 0.25	# proportional change in occupancy    R>0 represents a decline and R < 0 an increase. 
psi1 <- disturbshp$psiavg       # initial occupancy probability
p <- det		# detection probability
alpha <-0.05	# significance level
pow <- 0.8		# target power level
SS <- (calcSFormula(K1=K,K2=K,p1=p,p2=p,psi1,R,alpha,pow))/21
disturbshp$Sample25 <-SS
hist(disturbshp$Sample25)
#
colors<-mypallete(5)[cut(disturbshp$Sample25,5)] #
plot(disturbshp,col=colors) #
####10% decline

K <- 21		# number of days
R <- 0.1	# proportional change in occupancy    R>0 represents a decline and R < 0 an increase. 
#psi1 <- disturbshp$psiavg       # initial occupancy probability
p <- det		# detection probability
alpha <-0.05	# significance level
pow <- 0.8		# target power level
SS <- (calcSFormula(K1=K,K2=K,p1=p,p2=p,psi1,R,alpha,pow))/21
disturbshp$Sample10 <-SS
hist(disturbshp$Sample10)
#
colors<-mypallete(5)[cut(disturbshp$Sample10,5)] # 
plot(disturbshp,col=colors) #

proj4string(disturbshp)<-"+proj=utm +zone=19 +datum=NAD83 +units=m +no_defs +ellps=GRS80 +towgs84=0,0,0"
writeOGR(disturbshp,dsn=("C://Users//alessio.mortelliti//Documents//ArcGIS"),layer="Sampling_protocol_fisher",driver="ESRI Shapefile")






















