#Script prepared by Alessio Mortelliti, Allison M. Brehm and Bryn Evans and and to analyze data for the paper "LUmbrella effect in the monitoring protocols for mammals in the Northeast US.".
#Please contact Alessio Mortelliti alessio.mortelliti@maine.edu if you have any questions or concerns or if you would like to use the data associated with this paper
#The following script performs the occupancy analyses (multiple season occupancy models) and calculates the required sampling effort for a given management objective. 

library(unmarked)
library(AICcmodavg)

stweasel<-read.csv(file="Short_weasel_Official_pooled.csv",header=TRUE)

sites<-read.table(file="covariates.txt",header=TRUE)


################
#open detection history file
BT<-stweasel
colnames(BT)[1] <- "site"
colnames(sites)[1] <- "site"
BTm<-data.frame(merge(sites,BT, by='site'))
BT1<-BTm[,29:259]
days<-seq(1:33)
days2 <- matrix(days, nrow(BT1), 231, byrow=T)                   #231=4 summers +3 winters
season<-seq()
season <- as.character(c('summer','winter','summer','winter','summer','winter','summer'))
season2 <- matrix(season, nrow(BT1), 7, byrow=TRUE)


umf <- unmarkedMultFrame(y = BT1,siteCovs = sites, numPrimary = 7,yearlySiteCovs=list(season=season2),obsCovs=list(days=days2))

####################################
#######selection for p (detection probability) ######
######################################
fm0 <- colext(~1, ~1, ~1, ~1, umf)
fm01 <- colext(~1, ~1, ~1, ~days, umf)
fm02 <- colext(~1, ~1, ~1, ~I(days^2), umf)
fm03 <- colext(~1, ~1, ~1, ~log(days), umf)
fm04 <- colext(~1, ~1, ~1, ~factor(season), umf)
fm05 <- colext(~1, ~1, ~1, ~Dist_300m, umf)
fm06 <- colext(~1, ~1, ~1, ~Dist_1k, umf)
fm07 <- colext(~1, ~1, ~1, ~Dist_3k, umf)
fm08 <- colext(~1, ~1, ~1, ~Dist_6k, umf)
fm09 <- colext(~1, ~1, ~1, ~LAT, umf)
fm010 <- colext(~1, ~1, ~1, ~Prop_Hard_300, umf)
fm011 <- colext(~1, ~1, ~1, ~Prop_Hard_1k, umf)
fm013 <- colext(~1, ~1, ~1, ~factor(season)+I(days^2), umf)
fm014 <- colext(~1, ~1, ~1, ~LAT+I(days^2), umf)

models <- fitList('psi(.)gam(.)eps(.)p(.)' = fm0,
'psi(.)gam(.)eps(.)p(d)' = fm01,
'psi(.)gam(.)eps(.)p(d^2)' = fm02,
'psi(.)gam(.)eps(.)p(logd)' = fm03,
'psi(.)gam(.)eps(.)p(season)' = fm04,
'psi(.)gam(.)eps(.)p(Disturbance_300m)' = fm05, 
'psi(.)gam(.)eps(.)p(Dist_1k)' = fm06,
'psi(.)gam(.)eps(.)p(Dist_3k)' = fm07,
'psi(.)gam(.)eps(.)p(Dist_6k)' = fm08,
'psi(.)gam(.)eps(.)p(LAT)' = fm09,
'psi(.)gam(.)eps(.)p(Prop_Hard_300)'= fm010,
'psi(.)gam(.)eps(.)p(Prop_Hard_1k)'= fm011,
'psi(.)gam(.)eps(.)p(factor(season)+I(days^2)))'= fm013,
'psi(.)gam(.)eps(.)p(LAT+I(days^2)))'= fm014)

ms <- modSel(models)
print(ms)


  ####################################
   #######selection for PSI ############################################
fm2 <- colext(~Dist_300m, ~1, ~1, ~I(days^2), umf)                                                                             
fm3 <- colext(~Dist_1k, ~1, ~1, ~I(days^2), umf)            
fm4 <- colext(~Dist_3k, ~1, ~1, ~I(days^2), umf)                                                                             
fm5 <- colext(~Dist_6k, ~1, ~1, ~I(days^2), umf)                                                                        
fm7 <- colext(~Prop_Hard_300, ~1, ~1, ~I(days^2), umf)                                                                         
fm8 <- colext(~Prop_Hard_1k , ~1, ~1, ~I(days^2), umf)                                                                         
fm9 <- colext(~LAT, ~1, ~1, ~I(days^2), umf)                                                                            
fm10 <- colext(~1, ~1, ~1, ~I(days^2), umf)                                                                            
fm11 <- colext(~Prop_Hard_300+Dist_3k, ~1, ~1, ~I(days^2), umf)                                                                            


models <- fitList(
'psi(Dist_300m)gam(.)eps(.)p(I(days^2))' = fm2,
'psi(Dist_1k)gam(.)eps(.)p(I(days^2))' = fm3,

'psi(Dist_3k)gam(.)eps(.)p(I(days^2))' = fm4,
'psi(Dist_6k)gam(.)eps(.)p(I(days^2))' = fm5,
'psi(Prop_Hard_300)gam(.)eps(.)p(I(days^2))' = fm7,
'psi(Prop_Hard_1k)gam(.)eps(.)p(I(days^2))' = fm8,
 'psi(LAT)gam(.)eps(.)p(I(days^2))' = fm9, 
'psi(.)gam(.)eps(.)p(I(days^2))' = fm10, 
'psi(Prop_Hard_300+Dist_3k)gam(.)eps(.)p(I(days^2))' = fm11)
ms <- modSel(models)                                       


####################################
  #######selection for gamma ############################################
fm11 <- colext(~1, ~Dist_300m,~ 1, ~I(days^2), umf)
fm12 <- colext(~1, ~Dist_1k,~ 1, ~I(days^2), umf)
fm13 <- colext(~1, ~Dist_3k,~ 1, ~I(days^2), umf)
fm14 <- colext(~1, ~Dist_6k,~ 1, ~I(days^2), umf)
fm16 <- colext(~1, ~Prop_Hard_300,~ 1, ~I(days^2), umf)
fm17 <- colext(~1, ~Prop_Hard_1k,~ 1, ~I(days^2), umf)
fm18 <- colext(~1, ~LAT,~ 1, ~I(days^2), umf)
fm19 <- colext(~1, ~1,~ 1, ~I(days^2), umf)
fm20 <- colext(~1, ~Prop_Hard_1k +Dist_1k,~ 1, ~I(days^2), umf)


models <- fitList(
'psi(1)gam(Dist_300m)eps(.)p(I(days^2))' = fm11,
'psi(1)gam(Dist_1k)eps(.)p(I(days^2))' = fm12,
'psi(1)gam(Dist_3k)eps(.)p(I(days^2))' = fm13,
'psi(1)gam(Dist_6k)eps(.)p(I(days^2))' = fm14,
'psi(1)gam(Prop_Hard_300)eps(.)p(I(days^2))' = fm16,
'psi(1)gam(Prop_Hard_1k)eps(.)p(I(days^2))' = fm17,
'psi(1)gam(LAT)eps(.)p(I(days^2))' = fm18,
'psi(1)gam(.)eps(.)p(I(days^2))' = fm19,
'psi(1)gam(Prop_Hard_1k +Dist_1k)eps(.)p(I(days^2))' = fm20)

ms <- modSel(models)
print(ms)


####################################
   #######selection for epsilon ############################################
fm11b <- colext(~1, ~Prop_Hard_1k +Dist_1k,~ Dist_300m, ~I(days^2), umf)
fm12b <- colext(~1, ~Prop_Hard_1k +Dist_1k,~Dist_1k , ~I(days^2), umf)
fm13b <- colext(~1, ~Prop_Hard_1k +Dist_1k,~Dist_3k , ~I(days^2), umf)
fm14b <- colext(~1, ~Prop_Hard_1k +Dist_1k,~ Dist_6k, ~I(days^2), umf)
fm16b <- colext(~1, ~Prop_Hard_1k +Dist_1k,~ Prop_Hard_300, ~I(days^2), umf)
fm17b <- colext(~1, ~Prop_Hard_1k +Dist_1k,~ Prop_Hard_1k, ~I(days^2), umf)
fm18b <- colext(~1, ~Prop_Hard_1k +Dist_1k,~LAT , ~I(days^2), umf)
fm19b <- colext(~1, ~Prop_Hard_1k +Dist_1k,~ 1, ~I(days^2), umf)
null <- colext(~1, ~1, ~1, ~1, umf)     

models <- fitList(
'psi(1)gam(Prop_Hard_1k +Dist_1k)eps(Dist_300m)p(I(days^2))' = fm11b,
'psi(1)gam(Prop_Hard_1k +Dist_1k)eps(Dist_1k.)p(I(days^2))' = fm12b,
'psi(1)gam(Prop_Hard_1k +Dist_1k)eps(Dist_3k.)p(I(days^2))' = fm13b,
'psi(1)gam(Prop_Hard_1k +Dist_1k)eps(Dist_6k.)p(I(days^2))' = fm14b,
'psi(1)gam(Prop_Hard_1k +Dist_1k)eps(Prop_Hard_300)p(I(days^2))' = fm16b,
'psi(1)gam(Prop_Hard_1k +Dist_1k)eps(Prop_Hard_1k)p(I(days^2))' = fm17b,
'psi(1)gam(Prop_Hard_1k +Dist_1k)eps(LAT.)p(I(days^2))' = fm18b,
'psi(1)gam(Prop_Hard_1k +Dist_1k)eps(.)p(I(days^2))' = fm19b,
 'Null' = null)         

ms <- modSel(models, nullmod="Null")

print(ms)

#below we save the outputs
ms2 <- as(ms, "data.frame")
write.csv(ms2, file="STweaselallyears.csv") 
 
 ###############FIGURE##################
#######################################


 tiff(file = "STweasel.tiff",width = 2800, height = 1800, compression = 'lzw',  units = "px", res = 300)     #note that in the figure below I am using standard errors rather than confidence intervals


  op <- par(mfrow=c(2,2), mar=c(5, 4, 4, 2) + 0.1)
  
#DETECTION as function of days (Dst6k constant)
Prop_Hard_300=seq(min(sites$Prop_Hard_300), max(sites$Prop_Hard_300), length=16)
Prop_Hard_1k=seq(min(sites$Prop_Hard_1k), max(sites$Prop_Hard_1k), length=16)
Dist_300m=  seq(min(sites$Dist_300m), max(sites$Dist_300m), length=16)
Dist_3k= seq(min(sites$Dist_3k), max(sites$Dist_3k), length=16)   #keep this average
Dist_6k= seq(mean(sites$Dist_6k),mean (sites$Dist_6k), length=16)

days=seq(1,33,length=16)
LAT=seq(min(sites$LAT), max(sites$LAT), length=16)
nd<-data.frame(cbind(Prop_Hard_300,Prop_Hard_1k,Dist_300m,Dist_3k,days,Dist_6k))

E.col <- predict(fm19b, type="det",newdata=nd, appendData=FALSE)
G<-nd$days[1:16]
Gcol<-E.col$Predicted[1:16]
Gcolu<-E.col$lower[1:16]
Gcold<-E.col$upper[1:16]
plot(G, Gcol,xlim=c(1,33), axes=F,ylim=c(0,0.4), type="l", lwd=3,frame=F,                          xlab="days",
ylab="Detection probability", cex.lab=1.2, cex.axis=1)
axis(1,at=c(1,8,16,24,32))
axis(2,at=c(0,0.2,0.4,0.8,1) ) # 

polygon(c(rev(G),G),c(rev(Gcolu),Gcold), col = rgb(.8,.5,.5,.2),  border = NA)




#COLONIZATION DISTURbANCE

Prop_Hard_1k=seq(mean(sites$Prop_Hard_1k), mean(sites$Prop_Hard_1k), length=16)
Dist_1k=  seq(min(sites$Dist_1k), max(sites$Dist_1k), length=16)

nd<-data.frame(cbind(Prop_Hard_1k,Dist_1k,days))

E.col <- predict(fm19b, type="col",newdata=nd, appendData=FALSE)
G<-nd$Dist_1k[1:16]
Gcol<-E.col$Predicted[1:16]
Gcolu<-E.col$lower[1:16]
Gcold<-E.col$upper[1:16]
plot(G, Gcol,xlim=c(min(Dist_1k),max(Dist_1k)), axes=F,ylim=c(0,1), type="l", lwd=3,frame=F, 
xlab="Disturbance (1k)",
ylab="Colonization probability", cex.lab=1.2, cex.axis=1)
axis(1,at=c(1.12,2.98,5.08,7.06))
axis(2,at=c(0,0.2,0.4,0.6,0.8,1) ) # labels=c("1","6","11","16" )
polygon(c(rev(G),G),c(rev(Gcolu),Gcold), col = rgb(.8,.5,.5,.2), border = NA)


#COLONIZATION Hardwoos

Dist_1k=seq(mean(sites$Dist_1k), mean(sites$Dist_1k), length=16)
Prop_Hard_1k=  seq(min(sites$Prop_Hard_1k), max(sites$Prop_Hard_1k), length=16)

nd<-data.frame(cbind(Prop_Hard_1k,Dist_1k))

E.col <- predict(fm19b, type="col",newdata=nd, appendData=FALSE)
G<-nd$Prop_Hard_1k[1:16]
Gcol<-E.col$Predicted[1:16]
Gcolu<-E.col$lower[1:16]
Gcold<-E.col$upper[1:16]
plot(G, Gcol,xlim=c(min(Prop_Hard_1k),max(Prop_Hard_1k)), axes=F,ylim=c(0,1), type="l", lwd=3,frame=F, 
xlab="Proportion hardwood (1k)",
ylab="Colonization probability", cex.lab=1.2, cex.axis=1)
axis(1,at=c(0, 0.25,0.5,0.75,1))
axis(2,at=c(0,0.2,0.4,0.6,0.8,1) ) # labels=c("1","6","11","16" )
polygon(c(rev(G),G),c(rev(Gcolu),Gcold), col = rgb(.8,.5,.5,.2), border = NA)





title(outer=T,adj=0.5,main = list("Short-tailed weasel", cex=1.3,col="black", 
font=1 )  , line = -2)

dev.off()





simhist <- function(S,K,psi,p){
  h <- matrix(NA,S,K)
  z <- rbinom(S,1,psi)
  for (ii in 1:S){
    h[ii,] <- rbinom(K,1,p*z[ii])
  }
  return(h)
}

## Log-likelihood function for the occupancy model
loglik <- function(param, h){
  s <- dim(h)[1] # nr sites
  k <- dim(h)[2] # nr sampling occasions
  psi <- 1/(1+exp(-param[1]))  # to probabilities
  p <- 1/(1+exp(-param[2]))
  d <- sum(sum(h)) # summary statistics
  Sd <- sum(rowSums(h)>0)
  loglik <- -(Sd*log(psi)+d*log(p)+(k*Sd-d)*log(1-p)+(s-Sd)*log((1-psi)+psi*(1-p)^k))
  return(loglik)
}

## Analyze two datasets with different psi and different p  
fitmA <-function(h1,h2){
  fm1 <- optim(par=runif(2), fn=loglik, h=h1, hessian=T)
  fm2 <- optim(par=runif(2), fn=loglik, h=h2, hessian=T)
  VC1 <- try(solve(fm1$hessian),silent = TRUE)
  VC2 <- try(solve(fm2$hessian),silent = TRUE)  
  pars <- 1/(1+exp(-c(fm1$par,fm2$par)))    # to probabilities
  if ((class(VC1)=="try-error")||(class(VC2)=="try-error")){
    SEs <- rep(NA,4)
  }else{
    SEs <- c(sqrt(diag(VC1))*pars[1:2]*(1-pars[1:2]),sqrt(diag(VC2))*pars[3:4]*(1-pars[3:4]))
  }
  psi1 <- list(est = pars[1], se = SEs[1]) # arrange output
  p1 <- list(est = pars[2], se = SEs[2])
  psi2 <- list(est = pars[3], se = SEs[3])
  p2 <- list(est = pars[4], se = SEs[4])
  myres <- list(psi1 = psi1, p1 = p1, psi2 = psi2, p2 = p2,L = fm1$value + fm2$value)	
  return(myres)
}

## Run one simulation and do Wald test on probability scale
run1PAsim <- function(S1,S2,K1,K2,p1,p2,psi1,R,alpha){
  # simulate detection histories
  h1<-simhist(S=S1,K=K1,psi=psi1,p=p1)
  h2<-simhist(S=S2,K=K2,psi=psi1*(1-R),p=p2)
  # fit model
  fmA <-fitmA(h1,h2)
  # test for significance	
  Wald <- abs(fmA$psi1$est - fmA$psi2$est )/sqrt(fmA$psi1$se^2 + fmA$psi2$se^2)>qnorm(1-alpha/2)
  return(Wald)
}

## Run power analysis simulations 
runPowerSims <- function(S1,S2,K1,K2,p1,p2,psi1,R,alpha,nsims){
  powcnt <- 0
  okcnt <- 0
  t1 <- proc.time()
  for (ii in 1:nsims){
    cat('\r',ii); flush.console()
    res <- run1PAsim(S1=S1,S2=S2,K1=K1,K2=K2,p1=p1,p2=p2,psi1=psi1,R=R,alpha=alpha)
    if (is.finite(res)){
	    powcnt <- powcnt + res
	    okcnt <- okcnt + 1
    }
  }
  power <- powcnt/okcnt
  tdiff <- proc.time()-t1
  cat("\r","power (Wald test) = ", power[1],"\n")
  if (okcnt!=nsims){ 
	cat(nsims-okcnt, "simulations discarded (due to failed VC calculation)","\n")
  }  
  cat("elapsed time = ", tdiff[3] , " seconds\n\n\n") 
  return(c(power,okcnt))
}

## Calculate the power of a design using the formula in ms
calcPowerFormula <- function(S1,S2,K1,K2,p1,p2,psi1,R,alpha){
  psi2 <- psi1*(1-R)
  pp1 <- 1-(1-p1)^K1
  pp2 <- 1-(1-p2)^K2
  F1 <- (1-pp1)/(pp1-K1*p1*(1-p1)^(K1-1))
  F2 <- (1-pp2)/(pp2-K2*p2*(1-p2)^(K2-1))
  var1 <- psi1*(1-psi1+F1)/S1
  var2 <- psi2*(1-psi2+F2)/S2
  limL <- (+qnorm(1-alpha/2)*(sqrt(var1+var2))-(psi1-psi2))/sqrt(var1+var2)
  limU <- (-qnorm(1-alpha/2)*(sqrt(var1+var2))-(psi1-psi2))/sqrt(var1+var2)
  G <- 1 - pnorm(limL) + pnorm(limU)
  return(G)
}

## Determine the required sample size using the formula in ms
calcSFormula <- function(K1,K2,p1,p2,psi1,R,alpha,pow){
  psi2 <- psi1*(1-R)
  pp1 <- 1-(1-p1)^K1
  pp2 <- 1-(1-p2)^K2
  F1 <- (1-pp1)/(pp1-K1*p1*(1-p1)^(K1-1))
  F2 <- (1-pp2)/(pp2-K2*p2*(1-p2)^(K2-1))
  f1 <- psi1*(1-psi1+F1)
  f2 <- psi2*(1-psi2+F2)
  S <- (f1+f2)*((qnorm(1-alpha/2)+qnorm(pow))/(psi1-psi2))^2
  return(ceiling(S))
}

# loading the packages
library(raster)
library(rgeos)
library(rgdal)

# loading the shapefile
disturbshp<-readOGR("C://Users//alessio.mortelliti//Documents//ArcGIS//TownshipMARTEN//Township_Dissolve_Any_Survey_Effort_Shapefile.shp")

# plotting to see if it is nice and correct
 plot(disturbshp) 
summary(disturbshp)

# to see the table
head(disturbshp@data)
disturbshp
colnames(disturbshp@data) <- c("TOWN",  "COUNTY","Dist_300m", "Dist_1k","Dist_3k","Dist_6k","Prop_Hard_300","Prop_Hard_1k","LAT","LONG")
disturbshp$psiconst<-1
# 
mypallete<-colorRampPalette(c("lightpink","yellow","orange","green"))

#Extract coefficients
cf<-as.data.frame(coef(fm19b))

#predict psi, col,gam and p
psi<-exp( cf[1,1])/(1+exp( cf[1,1]))
col<- exp(cf[2,1]+cf[3,1]*disturbshp$Prop_Hard_1k+cf[4,1]*disturbshp$Dist_1k)/(1+exp(cf[2,1]+cf[3,1]*disturbshp$Prop_Hard_1k+cf[4,1]*disturbshp$Dist_1k))
ext<- exp(cf[5,1])
det<-exp( cf[6,1] + cf[7,1]*10)/(1+cf[6,1] + cf[7,1]*1)                    

#calculate psi for each of 4 years
psi2<- psi*ext+   (1-ext)*col
psi3<- psi2*ext+   (1-ext)*col
psi4<- psi3*ext+   (1-ext)*col

disturbshp$psiavg<-(psi+psi2+psi3+psi4)/4
head(disturbshp@data)


#calculating p* (i.e. cumulative detection probability) - which is the probability of detecting the species at least once during x days
px<- 1-(1-det)^21
min(px)
mean(px)
hist(px)



####
K <- 21		# number of days
R <-0.5	# proportional change in occupancy    
psi1 <- disturbshp$psiavg       # initial occupancy probability
p <- det		# detection probability
alpha <-0.05	# significance level
pow <- 0.8		# target power level
SS <- (calcSFormula(K1=K,K2=K,p1=p,p2=p,psi1,R,alpha,pow))/21
disturbshp$Sample50 <-SS
hist(disturbshp$Sample50)
# 
colors<-mypallete(5)[cut(disturbshp$Sample50,5)] # 
plot(disturbshp,col=colors) # 

####25% decline

 K <- 21		# number of days
R <- 0.25	# proportional change in occupancy    R>0 represents a decline and R < 0 an increase. 
psi1 <- disturbshp$psiavg       # initial occupancy probability
p <- det		# detection probability
alpha <-0.05	# significance level
pow <- 0.8		# target power level
SS <- (calcSFormula(K1=K,K2=K,p1=p,p2=p,psi1,R,alpha,pow))/21
disturbshp$Sample25 <-SS
hist(disturbshp$Sample25)
# cut the colors depeding on the disturbance level
colors<-mypallete(5)[cut(disturbshp$Sample25,5)] # you can change the 100 value to whatever break of colors you want
# plot
plot(disturbshp,col=colors) # it takes a while

####10% decline

K <- 21		# number of days
R <- 0.1	# proportional change in occupancy    R>0 represents a decline and R < 0 an increase. 
#psi1 <- disturbshp$psiavg       # initial occupancy probability
p <- det		# detection probability
alpha <-0.05	# significance level
pow <- 0.8		# target power level
SS <- (calcSFormula(K1=K,K2=K,p1=p,p2=p,psi1,R,alpha,pow))/21
disturbshp$Sample10 <-SS
hist(disturbshp$Sample10)
# 
colors<-mypallete(5)[cut(disturbshp$Sample10,5)] # 
plot(disturbshp,col=colors) # 

proj4string(disturbshp)<-"+proj=utm +zone=19 +datum=NAD83 +units=m +no_defs +ellps=GRS80 +towgs84=0,0,0"
writeOGR(disturbshp,dsn=("C://Users//alessio.mortelliti//Documents//ArcGIS"),layer="Sampling_protocol_STweasel",driver="ESRI Shapefile")





