require(readxl)
require(writexl)
require(dplyr)
require(ggplot2)
require(ggpubr)

### set working directory where files are stored ###

#### load data ####
marten<- read_excel("MARTENSampling_protocol_TableToExcel.xlsx")
bear<- read_excel("Sampling_protocol_bear_TableToExcel.xlsx")
bobcat<- read_excel("Sampling_protocol_bobcat_TableToExcel.xlsx")
coyote<- read_excel("Sampling_protocol_coyote_TableToExcel.xlsx")
deer<- read_excel("Sampling_protocol_deer_TableToExcel.xlsx")
fisher<- read_excel("Sampling_protocol_fisher_TableToExcel.xlsx")
lynx<- read_excel("Sampling_protocol_lynx_protectionzone_TableToExcel.xlsx")
moose<- read_excel("Sampling_protocol_moose_TableToExcel.xlsx")
porcupine<- read_excel("Sampling_protocol_porcupine_TableToExcel.xlsx")
raccoon<- read_excel("Sampling_protocol_raccoon_TableToExcel.xlsx")
redfox<- read_excel("Sampling_protocol_redfox_TableToExcel.xlsx")
snowshoehare<- read_excel("Sampling_protocol_snowshoehare_TableToExcel.xlsx")
squirrel<- read_excel("Sampling_protocol_squirrel_TableToExcel.xlsx")
stweasel<- read_excel("Sampling_protocol_STweasel_TableToExcel.xlsx")

marten<-as.data.frame(marten)
bear<-as.data.frame(bear)
bobcat<-as.data.frame(bobcat)
coyote<-as.data.frame(coyote)
deer<-as.data.frame(deer)
fisher<-as.data.frame(fisher)
lynx<-as.data.frame(lynx)
moose<-as.data.frame(moose)
porcupine<-as.data.frame(porcupine)
redfox<-as.data.frame(redfox)
snowshoehare<-as.data.frame(snowshoehare)
squirrel<-as.data.frame(squirrel)
stweasel<-as.data.frame(stweasel)


#### Change column names so that when we merge later we have the species in the name ####

names(marten)[names(marten) == "Sampl50"] <- "martenSampl50"
names(marten)[names(marten) == "Sampl25"] <- "martenSampl25"
names(marten)[names(marten) == "Sampl10"] <- "martenSampl10"

names(bear)[names(bear) == "Sampl50"] <- "bearSampl50"
names(bear)[names(bear) == "Sampl25"] <- "bearSampl25"
names(bear)[names(bear) == "Sampl10"] <- "bearSampl10"

names(bobcat)[names(bobcat) == "Sampl50"] <- "bobcatSampl50"
names(bobcat)[names(bobcat) == "Sampl25"] <- "bobcatSampl25"
names(bobcat)[names(bobcat) == "Sampl10"] <- "bobcatSampl10"

names(coyote)[names(coyote) == "Sampl50"] <- "coyoteSampl50"
names(coyote)[names(coyote) == "Sampl25"] <- "coyoteSampl25"
names(coyote)[names(coyote) == "Sampl10"] <- "coyoteSampl10"

names(deer)[names(deer) == "Sampl50"] <- "deerSampl50"
names(deer)[names(deer) == "Sampl25"] <- "deerSampl25"
names(deer)[names(deer) == "Sampl10"] <- "deerSampl10"

names(fisher)[names(fisher) == "Sampl50"] <- "fisherSampl50"
names(fisher)[names(fisher) == "Sampl25"] <- "fisherSampl25"
names(fisher)[names(fisher) == "Sampl10"] <- "fisherSampl10"

names(lynx)[names(lynx) == "Sampl50"] <- "lynxSampl50"
names(lynx)[names(lynx) == "Sampl25"] <- "lynxSampl25"
names(lynx)[names(lynx) == "Sampl10"] <- "lynxSampl10"

names(moose)[names(moose) == "Sampl50"] <- "mooseSampl50"
names(moose)[names(moose) == "Sampl25"] <- "mooseSampl25"
names(moose)[names(moose) == "Sampl10"] <- "mooseSampl10"

names(porcupine)[names(porcupine) == "Sampl50"] <- "porcupineSampl50"
names(porcupine)[names(porcupine) == "Sampl25"] <- "porcupineSampl25"
names(porcupine)[names(porcupine) == "Sampl10"] <- "porcupineSampl10"

names(raccoon)[names(raccoon) == "Sampl50"] <- "raccoonSampl50"
names(raccoon)[names(raccoon) == "Sampl25"] <- "raccoonSampl25"
names(raccoon)[names(raccoon) == "Sampl10"] <- "raccoonSampl10"

names(redfox)[names(redfox) == "Sampl50"] <- "redfoxSampl50"
names(redfox)[names(redfox) == "Sampl25"] <- "redfoxSampl25"
names(redfox)[names(redfox) == "Sampl10"] <- "redfoxSampl10"

names(snowshoehare)[names(snowshoehare) == "Sampl50"] <- "snowshoehareSampl50"
names(snowshoehare)[names(snowshoehare) == "Sampl25"] <- "snowshoehareSampl25"
names(snowshoehare)[names(snowshoehare) == "Sampl10"] <- "snowshoehareSampl10"

names(squirrel)[names(squirrel) == "Sampl50"] <- "squirrelSampl50"
names(squirrel)[names(squirrel) == "Sampl25"] <- "squirrelSampl25"
names(squirrel)[names(squirrel) == "Sampl10"] <- "squirrelSampl10"

names(stweasel)[names(stweasel) == "Sampl50"] <- "stweaselSampl50"
names(stweasel)[names(stweasel) == "Sampl25"] <- "stweaselSampl25"
names(stweasel)[names(stweasel) == "Sampl10"] <- "stweaselSampl10"


#### First remove areas where marten occupancy is below 0.2 ####
marten<-subset(marten, marten$psiavg >= 0.2)

#### ** ####
#### ** ####
#### ** ####

#### Subset Marten Low, Medium, and High effort at 25% sampling effort ####

martenlow<- subset(marten, martenSampl25 <= 22)

martenmed<- subset(marten, martenSampl25 >22 & martenSampl25 <= 33)

martenhigh<- subset(marten, martenSampl25 > 33 & martenSampl25 <= 55)


#### ** ####
#### Low effort - Marten 25% change detection ####
#### ** ####

#### Marten and Bear ####
martenbear<-merge(martenlow, bear[,c("bearSampl50", "bearSampl25", "bearSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenbear$marten25_bear10<-ifelse(martenbear$bearSampl10 <= 22, "in", "out")
martenbear$marten25_bear25<-ifelse(martenbear$bearSampl25 <= 22, "in", "out")
martenbear$marten25_bear50<-ifelse(martenbear$bearSampl50 <= 22, "in", "out")

martenbear$marten25_bear10<-as.factor(martenbear$marten25_bear10)
martenbear$marten25_bear25<-as.factor(martenbear$marten25_bear25)
martenbear$marten25_bear50<-as.factor(martenbear$marten25_bear50)


summary(martenbear)
# bear 10% - 294/294 in
# bear 25% - 294/294 in
# bear 50% - 294/294 in


#### Marten and Bobcat ####
martenbobcat<-merge(martenlow, bobcat[,c("bobcatSampl50", "bobcatSampl25", "bobcatSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenbobcat$marten25_bobcat10<-ifelse(martenbobcat$bobcatSampl10 <= 22, "in", "out")
martenbobcat$marten25_bobcat25<-ifelse(martenbobcat$bobcatSampl25 <= 22, "in", "out")
martenbobcat$marten25_bobcat50<-ifelse(martenbobcat$bobcatSampl50 <= 22, "in", "out")

martenbobcat$marten25_bobcat10<-as.factor(martenbobcat$marten25_bobcat10)
martenbobcat$marten25_bobcat25<-as.factor(martenbobcat$marten25_bobcat25)
martenbobcat$marten25_bobcat50<-as.factor(martenbobcat$marten25_bobcat50)


summary(martenbobcat)
# bobcat 10% - 0/294 in
# bobcat 25% - 0/294 in
# bobcat 50% - 3/294 in



#### Marten and Coyote ####
martencoyote<-merge(martenlow, coyote[,c("coyoteSampl50", "coyoteSampl25", "coyoteSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martencoyote$marten25_coyote10<-ifelse(martencoyote$coyoteSampl10 <= 22, "in", "out")
martencoyote$marten25_coyote25<-ifelse(martencoyote$coyoteSampl25 <= 22, "in", "out")
martencoyote$marten25_coyote50<-ifelse(martencoyote$coyoteSampl50 <= 22, "in", "out")

martencoyote$marten25_coyote10<-as.factor(martencoyote$marten25_coyote10)
martencoyote$marten25_coyote25<-as.factor(martencoyote$marten25_coyote25)
martencoyote$marten25_coyote50<-as.factor(martencoyote$marten25_coyote50)


summary(martencoyote)
# coyote 10% - 0/294 in
# coyote 25% - 105/294 in
# coyote 50% - 287/294 in



#### Marten and Deer ####
martendeer<-merge(martenlow, deer[,c("deerSampl50", "deerSampl25", "deerSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martendeer$marten25_deer10<-ifelse(martendeer$deerSampl10 <= 22, "in", "out")
martendeer$marten25_deer25<-ifelse(martendeer$deerSampl25 <= 22, "in", "out")
martendeer$marten25_deer50<-ifelse(martendeer$deerSampl50 <= 22, "in", "out")

martendeer$marten25_deer10<-as.factor(martendeer$marten25_deer10)
martendeer$marten25_deer25<-as.factor(martendeer$marten25_deer25)
martendeer$marten25_deer50<-as.factor(martendeer$marten25_deer50)


summary(martendeer)
# deer 10% - 82/294 in
# deer 25% - 288/294 in
# deer 50% - 294/294 in



#### Marten and Fisher ####
martenfisher<-merge(martenlow, fisher[,c("fisherSampl50", "fisherSampl25", "fisherSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenfisher$marten25_fisher10<-ifelse(martenfisher$fisherSampl10 <= 22, "in", "out")
martenfisher$marten25_fisher25<-ifelse(martenfisher$fisherSampl25 <= 22, "in", "out")
martenfisher$marten25_fisher50<-ifelse(martenfisher$fisherSampl50 <= 22, "in", "out")

martenfisher$marten25_fisher10<-as.factor(martenfisher$marten25_fisher10)
martenfisher$marten25_fisher25<-as.factor(martenfisher$marten25_fisher25)
martenfisher$marten25_fisher50<-as.factor(martenfisher$marten25_fisher50)


summary(martenfisher)
# fisher 10% - 0/294 in
# fisher 25% - 294/294 in
# fisher 50% - 294/294 in


#### Marten and Lynx ####
martenlynx<-merge(martenlow, lynx[,c("lynxSampl50", "lynxSampl25", "lynxSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenlynx$marten25_lynx10<-ifelse(martenlynx$lynxSampl10 <= 22, "in", "out")
martenlynx$marten25_lynx25<-ifelse(martenlynx$lynxSampl25 <= 22, "in", "out")
martenlynx$marten25_lynx50<-ifelse(martenlynx$lynxSampl50 <= 22, "in", "out")

martenlynx$marten25_lynx10<-as.factor(martenlynx$marten25_lynx10)
martenlynx$marten25_lynx25<-as.factor(martenlynx$marten25_lynx25)
martenlynx$marten25_lynx50<-as.factor(martenlynx$marten25_lynx50)


summary(martenlynx)
# lynx 10% - 0/175 in
# lynx 25% - 0/175 in
# lynx 50% - 0/175 in


#### Marten and Moose ####
martenmoose<-merge(martenlow, moose[,c("mooseSampl50", "mooseSampl25", "mooseSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenmoose$marten25_moose10<-ifelse(martenmoose$mooseSampl10 <= 22, "in", "out")
martenmoose$marten25_moose25<-ifelse(martenmoose$mooseSampl25 <= 22, "in", "out")
martenmoose$marten25_moose50<-ifelse(martenmoose$mooseSampl50 <= 22, "in", "out")

martenmoose$marten25_moose10<-as.factor(martenmoose$marten25_moose10)
martenmoose$marten25_moose25<-as.factor(martenmoose$marten25_moose25)
martenmoose$marten25_moose50<-as.factor(martenmoose$marten25_moose50)


summary(martenmoose)
# moose 10% - 0/294 in
# moose 25% - 0/294 in
# moose 50% - 0/294 in



#### Marten and Porcupine ####
martenporcupine<-merge(martenlow, porcupine[,c("porcupineSampl50", "porcupineSampl25", "porcupineSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenporcupine$marten25_porcupine10<-ifelse(martenporcupine$porcupineSampl10 <= 22, "in", "out")
martenporcupine$marten25_porcupine25<-ifelse(martenporcupine$porcupineSampl25 <= 22, "in", "out")
martenporcupine$marten25_porcupine50<-ifelse(martenporcupine$porcupineSampl50 <= 22, "in", "out")

martenporcupine$marten25_porcupine10<-as.factor(martenporcupine$marten25_porcupine10)
martenporcupine$marten25_porcupine25<-as.factor(martenporcupine$marten25_porcupine25)
martenporcupine$marten25_porcupine50<-as.factor(martenporcupine$marten25_porcupine50)


summary(martenporcupine)
# porcupine 10% - 0/294 in
# porcupine 25% - 0/294 in
# porcupine 50% - 0/294 in


#### Marten and Raccoon ####
martenraccoon<-merge(martenlow, raccoon[,c("raccoonSampl50", "raccoonSampl25", "raccoonSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenraccoon$marten25_raccoon10<-ifelse(martenraccoon$raccoonSampl10 <= 22, "in", "out")
martenraccoon$marten25_raccoon25<-ifelse(martenraccoon$raccoonSampl25 <= 22, "in", "out")
martenraccoon$marten25_raccoon50<-ifelse(martenraccoon$raccoonSampl50 <= 22, "in", "out")

martenraccoon$marten25_raccoon10<-as.factor(martenraccoon$marten25_raccoon10)
martenraccoon$marten25_raccoon25<-as.factor(martenraccoon$marten25_raccoon25)
martenraccoon$marten25_raccoon50<-as.factor(martenraccoon$marten25_raccoon50)


summary(martenraccoon)
# raccoon 10% - 0/294 in
# raccoon 25% - 3/294 in
# raccoon 50% - 226/294 in



#### Marten and Red Fox ####
martenredfox<-merge(martenlow, redfox[,c("redfoxSampl50", "redfoxSampl25", "redfoxSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenredfox$marten25_redfox10<-ifelse(martenredfox$redfoxSampl10 <= 22, "in", "out")
martenredfox$marten25_redfox25<-ifelse(martenredfox$redfoxSampl25 <= 22, "in", "out")
martenredfox$marten25_redfox50<-ifelse(martenredfox$redfoxSampl50 <= 22, "in", "out")

martenredfox$marten25_redfox10<-as.factor(martenredfox$marten25_redfox10)
martenredfox$marten25_redfox25<-as.factor(martenredfox$marten25_redfox25)
martenredfox$marten25_redfox50<-as.factor(martenredfox$marten25_redfox50)


summary(martenredfox)
# redfox 10% - 0/294 in
# redfox 25% - 0/294 in
# redfox 50% - 55/294 in



#### Marten and Snowshoe hare ####
martensnowshoehare<-merge(martenlow, snowshoehare[,c("snowshoehareSampl50", "snowshoehareSampl25", "snowshoehareSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martensnowshoehare$marten25_snowshoehare10<-ifelse(martensnowshoehare$snowshoehareSampl10 <= 22, "in", "out")
martensnowshoehare$marten25_snowshoehare25<-ifelse(martensnowshoehare$snowshoehareSampl25 <= 22, "in", "out")
martensnowshoehare$marten25_snowshoehare50<-ifelse(martensnowshoehare$snowshoehareSampl50 <= 22, "in", "out")

martensnowshoehare$marten25_snowshoehare10<-as.factor(martensnowshoehare$marten25_snowshoehare10)
martensnowshoehare$marten25_snowshoehare25<-as.factor(martensnowshoehare$marten25_snowshoehare25)
martensnowshoehare$marten25_snowshoehare50<-as.factor(martensnowshoehare$marten25_snowshoehare50)


summary(martensnowshoehare)
# snowshoehare 10% - 6/294 in
# snowshoehare 25% - 294/294 in
# snowshoehare 50% - 294/294 in


#### Marten and Squirrel ####
martensquirrel<-merge(martenlow, squirrel[,c("squirrelSampl50", "squirrelSampl25", "squirrelSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martensquirrel$marten25_squirrel10<-ifelse(martensquirrel$squirrelSampl10 <= 22, "in", "out")
martensquirrel$marten25_squirrel25<-ifelse(martensquirrel$squirrelSampl25 <= 22, "in", "out")
martensquirrel$marten25_squirrel50<-ifelse(martensquirrel$squirrelSampl50 <= 22, "in", "out")

martensquirrel$marten25_squirrel10<-as.factor(martensquirrel$marten25_squirrel10)
martensquirrel$marten25_squirrel25<-as.factor(martensquirrel$marten25_squirrel25)
martensquirrel$marten25_squirrel50<-as.factor(martensquirrel$marten25_squirrel50)


summary(martensquirrel)
# squirrel 10% - 291/294 in
# squirrel 25% - 294/294 in
# squirrel 50% - 294/294 in



#### Marten and Short-tailed weasel ####
martenstweasel<-merge(martenlow, stweasel[,c("stweaselSampl50", "stweaselSampl25", "stweaselSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenstweasel$marten25_stweasel10<-ifelse(martenstweasel$stweaselSampl10 <= 22, "in", "out")
martenstweasel$marten25_stweasel25<-ifelse(martenstweasel$stweaselSampl25 <= 22, "in", "out")
martenstweasel$marten25_stweasel50<-ifelse(martenstweasel$stweaselSampl50 <= 22, "in", "out")

martenstweasel$marten25_stweasel10<-as.factor(martenstweasel$marten25_stweasel10)
martenstweasel$marten25_stweasel25<-as.factor(martenstweasel$marten25_stweasel25)
martenstweasel$marten25_stweasel50<-as.factor(martenstweasel$marten25_stweasel50)


summary(martenstweasel)
# stweasel 10% - 0/294 in
# stweasel 25% - 0/294 in
# stweasel 50% - 294/294 in


#### ** ####
#### Medium effort - Marten 25% change detection ####
#### ** ####

#### Marten and Bear ####
martenbear<-merge(martenmed, bear[,c("bearSampl50", "bearSampl25", "bearSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenbear$marten25_bear10<-ifelse(martenbear$bearSampl10 <= 33, "in", "out")
martenbear$marten25_bear25<-ifelse(martenbear$bearSampl25 <= 33, "in", "out")
martenbear$marten25_bear50<-ifelse(martenbear$bearSampl50 <= 33, "in", "out")

martenbear$marten25_bear10<-as.factor(martenbear$marten25_bear10)
martenbear$marten25_bear25<-as.factor(martenbear$marten25_bear25)
martenbear$marten25_bear50<-as.factor(martenbear$marten25_bear50)


summary(martenbear)
# bear 10% - 317/317 in
# bear 25% - 317/317 in
# bear 50% - 317/317 in


#### Marten and Bobcat ####
martenbobcat<-merge(martenmed, bobcat[,c("bobcatSampl50", "bobcatSampl25", "bobcatSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenbobcat$marten25_bobcat10<-ifelse(martenbobcat$bobcatSampl10 <= 33, "in", "out")
martenbobcat$marten25_bobcat25<-ifelse(martenbobcat$bobcatSampl25 <= 33, "in", "out")
martenbobcat$marten25_bobcat50<-ifelse(martenbobcat$bobcatSampl50 <= 33, "in", "out")

martenbobcat$marten25_bobcat10<-as.factor(martenbobcat$marten25_bobcat10)
martenbobcat$marten25_bobcat25<-as.factor(martenbobcat$marten25_bobcat25)
martenbobcat$marten25_bobcat50<-as.factor(martenbobcat$marten25_bobcat50)


summary(martenbobcat)
# bobcat 10% - 0/317 in
# bobcat 25% - 0/317 in
# bobcat 50% - 14/317 in



#### Marten and Coyote ####
martencoyote<-merge(martenmed, coyote[,c("coyoteSampl50", "coyoteSampl25", "coyoteSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martencoyote$marten25_coyote10<-ifelse(martencoyote$coyoteSampl10 <= 33, "in", "out")
martencoyote$marten25_coyote25<-ifelse(martencoyote$coyoteSampl25 <= 33, "in", "out")
martencoyote$marten25_coyote50<-ifelse(martencoyote$coyoteSampl50 <= 33, "in", "out")

martencoyote$marten25_coyote10<-as.factor(martencoyote$marten25_coyote10)
martencoyote$marten25_coyote25<-as.factor(martencoyote$marten25_coyote25)
martencoyote$marten25_coyote50<-as.factor(martencoyote$marten25_coyote50)


summary(martencoyote)
# coyote 10% - 0/317 in
# coyote 25% - 152/317 in
# coyote 50% - 317/317 in



#### Marten and Deer ####
martendeer<-merge(martenmed, deer[,c("deerSampl50", "deerSampl25", "deerSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martendeer$marten25_deer10<-ifelse(martendeer$deerSampl10 <= 33, "in", "out")
martendeer$marten25_deer25<-ifelse(martendeer$deerSampl25 <= 33, "in", "out")
martendeer$marten25_deer50<-ifelse(martendeer$deerSampl50 <= 33, "in", "out")

martendeer$marten25_deer10<-as.factor(martendeer$marten25_deer10)
martendeer$marten25_deer25<-as.factor(martendeer$marten25_deer25)
martendeer$marten25_deer50<-as.factor(martendeer$marten25_deer50)


summary(martendeer)
# deer 10% - 150/317 in
# deer 25% - 317/317 in
# deer 50% - 317/317 in



#### Marten and Fisher ####
martenfisher<-merge(martenmed, fisher[,c("fisherSampl50", "fisherSampl25", "fisherSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenfisher$marten25_fisher10<-ifelse(martenfisher$fisherSampl10 <= 33, "in", "out")
martenfisher$marten25_fisher25<-ifelse(martenfisher$fisherSampl25 <= 33, "in", "out")
martenfisher$marten25_fisher50<-ifelse(martenfisher$fisherSampl50 <= 33, "in", "out")

martenfisher$marten25_fisher10<-as.factor(martenfisher$marten25_fisher10)
martenfisher$marten25_fisher25<-as.factor(martenfisher$marten25_fisher25)
martenfisher$marten25_fisher50<-as.factor(martenfisher$marten25_fisher50)


summary(martenfisher)
# fisher 10% - 0/317 in
# fisher 25% - 317/317 in
# fisher 50% - 317/317 in


#### Marten and Lynx ####
martenlynx<-merge(martenmed, lynx[,c("lynxSampl50", "lynxSampl25", "lynxSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenlynx$marten25_lynx10<-ifelse(martenlynx$lynxSampl10 <= 33, "in", "out")
martenlynx$marten25_lynx25<-ifelse(martenlynx$lynxSampl25 <= 33, "in", "out")
martenlynx$marten25_lynx50<-ifelse(martenlynx$lynxSampl50 <= 33, "in", "out")

martenlynx$marten25_lynx10<-as.factor(martenlynx$marten25_lynx10)
martenlynx$marten25_lynx25<-as.factor(martenlynx$marten25_lynx25)
martenlynx$marten25_lynx50<-as.factor(martenlynx$marten25_lynx50)


summary(martenlynx)
# lynx 10% - 0/263 in
# lynx 25% - 0/263 in
# lynx 50% - 60/263 in


#### Marten and Moose ####
martenmoose<-merge(martenmed, moose[,c("mooseSampl50", "mooseSampl25", "mooseSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenmoose$marten25_moose10<-ifelse(martenmoose$mooseSampl10 <= 33, "in", "out")
martenmoose$marten25_moose25<-ifelse(martenmoose$mooseSampl25 <= 33, "in", "out")
martenmoose$marten25_moose50<-ifelse(martenmoose$mooseSampl50 <= 33, "in", "out")

martenmoose$marten25_moose10<-as.factor(martenmoose$marten25_moose10)
martenmoose$marten25_moose25<-as.factor(martenmoose$marten25_moose25)
martenmoose$marten25_moose50<-as.factor(martenmoose$marten25_moose50)


summary(martenmoose)
# moose 10% - 0/317 in
# moose 25% - 0/317 in
# moose 50% - 5/317 in



#### Marten and Porcupine ####
martenporcupine<-merge(martenmed, porcupine[,c("porcupineSampl50", "porcupineSampl25", "porcupineSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenporcupine$marten25_porcupine10<-ifelse(martenporcupine$porcupineSampl10 <= 33, "in", "out")
martenporcupine$marten25_porcupine25<-ifelse(martenporcupine$porcupineSampl25 <= 33, "in", "out")
martenporcupine$marten25_porcupine50<-ifelse(martenporcupine$porcupineSampl50 <= 33, "in", "out")

martenporcupine$marten25_porcupine10<-as.factor(martenporcupine$marten25_porcupine10)
martenporcupine$marten25_porcupine25<-as.factor(martenporcupine$marten25_porcupine25)
martenporcupine$marten25_porcupine50<-as.factor(martenporcupine$marten25_porcupine50)


summary(martenporcupine)
# porcupine 10% - 0/317 in
# porcupine 25% - 0/317 in
# porcupine 50% - 0/317 in


#### Marten and Raccoon ####
martenraccoon<-merge(martenmed, raccoon[,c("raccoonSampl50", "raccoonSampl25", "raccoonSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenraccoon$marten25_raccoon10<-ifelse(martenraccoon$raccoonSampl10 <= 33, "in", "out")
martenraccoon$marten25_raccoon25<-ifelse(martenraccoon$raccoonSampl25 <= 33, "in", "out")
martenraccoon$marten25_raccoon50<-ifelse(martenraccoon$raccoonSampl50 <= 33, "in", "out")

martenraccoon$marten25_raccoon10<-as.factor(martenraccoon$marten25_raccoon10)
martenraccoon$marten25_raccoon25<-as.factor(martenraccoon$marten25_raccoon25)
martenraccoon$marten25_raccoon50<-as.factor(martenraccoon$marten25_raccoon50)


summary(martenraccoon)
# raccoon 10% - 0/317 in
# raccoon 25% - 1/317 in
# raccoon 50% - 230/317 in



#### Marten and Red Fox ####
martenredfox<-merge(martenmed, redfox[,c("redfoxSampl50", "redfoxSampl25", "redfoxSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenredfox$marten25_redfox10<-ifelse(martenredfox$redfoxSampl10 <= 33, "in", "out")
martenredfox$marten25_redfox25<-ifelse(martenredfox$redfoxSampl25 <= 33, "in", "out")
martenredfox$marten25_redfox50<-ifelse(martenredfox$redfoxSampl50 <= 33, "in", "out")

martenredfox$marten25_redfox10<-as.factor(martenredfox$marten25_redfox10)
martenredfox$marten25_redfox25<-as.factor(martenredfox$marten25_redfox25)
martenredfox$marten25_redfox50<-as.factor(martenredfox$marten25_redfox50)


summary(martenredfox)
# redfox 10% - 0/317 in
# redfox 25% - 0/317 in
# redfox 50% - 61/317 in



#### Marten and Snowshoe hare ####
martensnowshoehare<-merge(martenmed, snowshoehare[,c("snowshoehareSampl50", "snowshoehareSampl25", "snowshoehareSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martensnowshoehare$marten25_snowshoehare10<-ifelse(martensnowshoehare$snowshoehareSampl10 <= 33, "in", "out")
martensnowshoehare$marten25_snowshoehare25<-ifelse(martensnowshoehare$snowshoehareSampl25 <= 33, "in", "out")
martensnowshoehare$marten25_snowshoehare50<-ifelse(martensnowshoehare$snowshoehareSampl50 <= 33, "in", "out")

martensnowshoehare$marten25_snowshoehare10<-as.factor(martensnowshoehare$marten25_snowshoehare10)
martensnowshoehare$marten25_snowshoehare25<-as.factor(martensnowshoehare$marten25_snowshoehare25)
martensnowshoehare$marten25_snowshoehare50<-as.factor(martensnowshoehare$marten25_snowshoehare50)


summary(martensnowshoehare)
# snowshoehare 10% - 105/317 in
# snowshoehare 25% - 317/317 in
# snowshoehare 50% - 317/317 in


#### Marten and Squirrel ####
martensquirrel<-merge(martenmed, squirrel[,c("squirrelSampl50", "squirrelSampl25", "squirrelSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martensquirrel$marten25_squirrel10<-ifelse(martensquirrel$squirrelSampl10 <= 33, "in", "out")
martensquirrel$marten25_squirrel25<-ifelse(martensquirrel$squirrelSampl25 <= 33, "in", "out")
martensquirrel$marten25_squirrel50<-ifelse(martensquirrel$squirrelSampl50 <= 33, "in", "out")

martensquirrel$marten25_squirrel10<-as.factor(martensquirrel$marten25_squirrel10)
martensquirrel$marten25_squirrel25<-as.factor(martensquirrel$marten25_squirrel25)
martensquirrel$marten25_squirrel50<-as.factor(martensquirrel$marten25_squirrel50)


summary(martensquirrel)
# squirrel 10% - 317/317 in
# squirrel 25% - 317/317 in
# squirrel 50% - 317/317 in

#### Marten and Short-tailed weasel ####
martenstweasel<-merge(martenmed, stweasel[,c("stweaselSampl50", "stweaselSampl25", "stweaselSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenstweasel$marten25_stweasel10<-ifelse(martenstweasel$stweaselSampl10 <= 33, "in", "out")
martenstweasel$marten25_stweasel25<-ifelse(martenstweasel$stweaselSampl25 <= 33, "in", "out")
martenstweasel$marten25_stweasel50<-ifelse(martenstweasel$stweaselSampl50 <= 33, "in", "out")

martenstweasel$marten25_stweasel10<-as.factor(martenstweasel$marten25_stweasel10)
martenstweasel$marten25_stweasel25<-as.factor(martenstweasel$marten25_stweasel25)
martenstweasel$marten25_stweasel50<-as.factor(martenstweasel$marten25_stweasel50)


summary(martenstweasel)
# stweasel 10% - 0/317 in
# stweasel 25% - 35/317 in
# stweasel 50% - 317/317 in
#### ** ####
#### High effort - Marten 25% change detection ####
#### ** ####

#### Marten and Bear ####
martenbear<-merge(martenhigh, bear[,c("bearSampl50", "bearSampl25", "bearSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenbear$marten25_bear10<-ifelse(martenbear$bearSampl10 <= 55, "in", "out")
martenbear$marten25_bear25<-ifelse(martenbear$bearSampl25 <= 55, "in", "out")
martenbear$marten25_bear50<-ifelse(martenbear$bearSampl50 <= 55, "in", "out")

martenbear$marten25_bear10<-as.factor(martenbear$marten25_bear10)
martenbear$marten25_bear25<-as.factor(martenbear$marten25_bear25)
martenbear$marten25_bear50<-as.factor(martenbear$marten25_bear50)


summary(martenbear)
# bear 10% - 119/119 in
# bear 25% - 119/119 in
# bear 50% - 119/119 in


#### Marten and Bobcat ####
martenbobcat<-merge(martenhigh, bobcat[,c("bobcatSampl50", "bobcatSampl25", "bobcatSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenbobcat$marten25_bobcat10<-ifelse(martenbobcat$bobcatSampl10 <= 55, "in", "out")
martenbobcat$marten25_bobcat25<-ifelse(martenbobcat$bobcatSampl25 <= 55, "in", "out")
martenbobcat$marten25_bobcat50<-ifelse(martenbobcat$bobcatSampl50 <= 55, "in", "out")

martenbobcat$marten25_bobcat10<-as.factor(martenbobcat$marten25_bobcat10)
martenbobcat$marten25_bobcat25<-as.factor(martenbobcat$marten25_bobcat25)
martenbobcat$marten25_bobcat50<-as.factor(martenbobcat$marten25_bobcat50)


summary(martenbobcat)
# bobcat 10% - 0/119 in
# bobcat 25% - 0/119 in
# bobcat 50% - 0/119 in



#### Marten and Coyote ####
martencoyote<-merge(martenhigh, coyote[,c("coyoteSampl50", "coyoteSampl25", "coyoteSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martencoyote$marten25_coyote10<-ifelse(martencoyote$coyoteSampl10 <= 55, "in", "out")
martencoyote$marten25_coyote25<-ifelse(martencoyote$coyoteSampl25 <= 55, "in", "out")
martencoyote$marten25_coyote50<-ifelse(martencoyote$coyoteSampl50 <= 55, "in", "out")

martencoyote$marten25_coyote10<-as.factor(martencoyote$marten25_coyote10)
martencoyote$marten25_coyote25<-as.factor(martencoyote$marten25_coyote25)
martencoyote$marten25_coyote50<-as.factor(martencoyote$marten25_coyote50)


summary(martencoyote)
# coyote 10% - 0/119 in
# coyote 25% - 96/119 in
# coyote 50% - 119/119 in



#### Marten and Deer ####
martendeer<-merge(martenhigh, deer[,c("deerSampl50", "deerSampl25", "deerSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martendeer$marten25_deer10<-ifelse(martendeer$deerSampl10 <= 55, "in", "out")
martendeer$marten25_deer25<-ifelse(martendeer$deerSampl25 <= 55, "in", "out")
martendeer$marten25_deer50<-ifelse(martendeer$deerSampl50 <= 55, "in", "out")

martendeer$marten25_deer10<-as.factor(martendeer$marten25_deer10)
martendeer$marten25_deer25<-as.factor(martendeer$marten25_deer25)
martendeer$marten25_deer50<-as.factor(martendeer$marten25_deer50)


summary(martendeer)
# deer 10% - 98/119 in
# deer 25% - 119/119 in
# deer 50% - 119/119 in



#### Marten and Fisher ####
martenfisher<-merge(martenhigh, fisher[,c("fisherSampl50", "fisherSampl25", "fisherSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenfisher$marten25_fisher10<-ifelse(martenfisher$fisherSampl10 <= 55, "in", "out")
martenfisher$marten25_fisher25<-ifelse(martenfisher$fisherSampl25 <= 55, "in", "out")
martenfisher$marten25_fisher50<-ifelse(martenfisher$fisherSampl50 <= 55, "in", "out")

martenfisher$marten25_fisher10<-as.factor(martenfisher$marten25_fisher10)
martenfisher$marten25_fisher25<-as.factor(martenfisher$marten25_fisher25)
martenfisher$marten25_fisher50<-as.factor(martenfisher$marten25_fisher50)


summary(martenfisher)
# fisher 10% - 28/119 in
# fisher 25% - 119/119 in
# fisher 50% - 119/119 in


#### Marten and Lynx ####
martenlynx<-merge(martenhigh, lynx[,c("lynxSampl50", "lynxSampl25", "lynxSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenlynx$marten25_lynx10<-ifelse(martenlynx$lynxSampl10 <= 55, "in", "out")
martenlynx$marten25_lynx25<-ifelse(martenlynx$lynxSampl25 <= 55, "in", "out")
martenlynx$marten25_lynx50<-ifelse(martenlynx$lynxSampl50 <= 55, "in", "out")

martenlynx$marten25_lynx10<-as.factor(martenlynx$marten25_lynx10)
martenlynx$marten25_lynx25<-as.factor(martenlynx$marten25_lynx25)
martenlynx$marten25_lynx50<-as.factor(martenlynx$marten25_lynx50)


summary(martenlynx)
# lynx 10% - 0/114 in
# lynx 25% - 0/114 in
# lynx 50% - 113/114 in


#### Marten and Moose ####
martenmoose<-merge(martenhigh, moose[,c("mooseSampl50", "mooseSampl25", "mooseSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenmoose$marten25_moose10<-ifelse(martenmoose$mooseSampl10 <= 55, "in", "out")
martenmoose$marten25_moose25<-ifelse(martenmoose$mooseSampl25 <= 55, "in", "out")
martenmoose$marten25_moose50<-ifelse(martenmoose$mooseSampl50 <= 55, "in", "out")

martenmoose$marten25_moose10<-as.factor(martenmoose$marten25_moose10)
martenmoose$marten25_moose25<-as.factor(martenmoose$marten25_moose25)
martenmoose$marten25_moose50<-as.factor(martenmoose$marten25_moose50)


summary(martenmoose)
# moose 10% - 0/119 in
# moose 25% - 0/119 in
# moose 50% - 116/119 in



#### Marten and Porcupine ####
martenporcupine<-merge(martenhigh, porcupine[,c("porcupineSampl50", "porcupineSampl25", "porcupineSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenporcupine$marten25_porcupine10<-ifelse(martenporcupine$porcupineSampl10 <= 55, "in", "out")
martenporcupine$marten25_porcupine25<-ifelse(martenporcupine$porcupineSampl25 <= 55, "in", "out")
martenporcupine$marten25_porcupine50<-ifelse(martenporcupine$porcupineSampl50 <= 55, "in", "out")

martenporcupine$marten25_porcupine10<-as.factor(martenporcupine$marten25_porcupine10)
martenporcupine$marten25_porcupine25<-as.factor(martenporcupine$marten25_porcupine25)
martenporcupine$marten25_porcupine50<-as.factor(martenporcupine$marten25_porcupine50)


summary(martenporcupine)
# porcupine 10% - 0/119 in
# porcupine 25% - 0/119 in
# porcupine 50% - 0/119 in


#### Marten and Raccoon ####
martenraccoon<-merge(martenhigh, raccoon[,c("raccoonSampl50", "raccoonSampl25", "raccoonSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenraccoon$marten25_raccoon10<-ifelse(martenraccoon$raccoonSampl10 <= 55, "in", "out")
martenraccoon$marten25_raccoon25<-ifelse(martenraccoon$raccoonSampl25 <= 55, "in", "out")
martenraccoon$marten25_raccoon50<-ifelse(martenraccoon$raccoonSampl50 <= 55, "in", "out")

martenraccoon$marten25_raccoon10<-as.factor(martenraccoon$marten25_raccoon10)
martenraccoon$marten25_raccoon25<-as.factor(martenraccoon$marten25_raccoon25)
martenraccoon$marten25_raccoon50<-as.factor(martenraccoon$marten25_raccoon50)


summary(martenraccoon)
# raccoon 10% - 0/119 in
# raccoon 25% - 0/119 in
# raccoon 50% - 111/119 in



#### Marten and Red Fox ####
martenredfox<-merge(martenhigh, redfox[,c("redfoxSampl50", "redfoxSampl25", "redfoxSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenredfox$marten25_redfox10<-ifelse(martenredfox$redfoxSampl10 <= 55, "in", "out")
martenredfox$marten25_redfox25<-ifelse(martenredfox$redfoxSampl25 <= 55, "in", "out")
martenredfox$marten25_redfox50<-ifelse(martenredfox$redfoxSampl50 <= 55, "in", "out")

martenredfox$marten25_redfox10<-as.factor(martenredfox$marten25_redfox10)
martenredfox$marten25_redfox25<-as.factor(martenredfox$marten25_redfox25)
martenredfox$marten25_redfox50<-as.factor(martenredfox$marten25_redfox50)


summary(martenredfox)
# redfox 10% - 0/119 in
# redfox 25% - 0/119 in
# redfox 50% - 22/119 in



#### Marten and Snowshoe hare ####
martensnowshoehare<-merge(martenhigh, snowshoehare[,c("snowshoehareSampl50", "snowshoehareSampl25", "snowshoehareSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martensnowshoehare$marten25_snowshoehare10<-ifelse(martensnowshoehare$snowshoehareSampl10 <= 55, "in", "out")
martensnowshoehare$marten25_snowshoehare25<-ifelse(martensnowshoehare$snowshoehareSampl25 <= 55, "in", "out")
martensnowshoehare$marten25_snowshoehare50<-ifelse(martensnowshoehare$snowshoehareSampl50 <= 55, "in", "out")

martensnowshoehare$marten25_snowshoehare10<-as.factor(martensnowshoehare$marten25_snowshoehare10)
martensnowshoehare$marten25_snowshoehare25<-as.factor(martensnowshoehare$marten25_snowshoehare25)
martensnowshoehare$marten25_snowshoehare50<-as.factor(martensnowshoehare$marten25_snowshoehare50)


summary(martensnowshoehare)
# snowshoehare 10% - 94/119 in
# snowshoehare 25% - 119/119 in
# snowshoehare 50% - 119/119 in




#### Marten and Squirrel ####
martensquirrel<-merge(martenhigh, squirrel[,c("squirrelSampl50", "squirrelSampl25", "squirrelSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martensquirrel$marten25_squirrel10<-ifelse(martensquirrel$squirrelSampl10 <= 55, "in", "out")
martensquirrel$marten25_squirrel25<-ifelse(martensquirrel$squirrelSampl25 <= 55, "in", "out")
martensquirrel$marten25_squirrel50<-ifelse(martensquirrel$squirrelSampl50 <= 55, "in", "out")

martensquirrel$marten25_squirrel10<-as.factor(martensquirrel$marten25_squirrel10)
martensquirrel$marten25_squirrel25<-as.factor(martensquirrel$marten25_squirrel25)
martensquirrel$marten25_squirrel50<-as.factor(martensquirrel$marten25_squirrel50)


summary(martensquirrel)
# squirrel 10% - 119/119 in
# squirrel 25% - 119/119 in
# squirrel 50% - 119/119 in

#### Marten and Short-tailed weasel ####
martenstweasel<-merge(martenhigh, stweasel[,c("stweaselSampl50", "stweaselSampl25", "stweaselSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenstweasel$marten25_stweasel10<-ifelse(martenstweasel$stweaselSampl10 <= 55, "in", "out")
martenstweasel$marten25_stweasel25<-ifelse(martenstweasel$stweaselSampl25 <= 55, "in", "out")
martenstweasel$marten25_stweasel50<-ifelse(martenstweasel$stweaselSampl50 <= 55, "in", "out")

martenstweasel$marten25_stweasel10<-as.factor(martenstweasel$marten25_stweasel10)
martenstweasel$marten25_stweasel25<-as.factor(martenstweasel$marten25_stweasel25)
martenstweasel$marten25_stweasel50<-as.factor(martenstweasel$marten25_stweasel50)


summary(martenstweasel)
# stweasel 10% - 0/119 in
# stweasel 25% - 119/119 in
# stweasel 50% - 119/119 in
