require(readxl)
require(writexl)
require(dplyr)
require(ggplot2)
require(ggpubr)

### set working directory where files are stored ###

#### load data ####
marten<- read_excel("MARTENSampling_protocol_TableToExcel.xlsx")
bear<- read_excel("Sampling_protocol_bear_TableToExcel.xlsx")
bobcat<- read_excel("Sampling_protocol_bobcat_TableToExcel.xlsx")
coyote<- read_excel("Sampling_protocol_coyote_TableToExcel.xlsx")
deer<- read_excel("Sampling_protocol_deer_TableToExcel.xlsx")
fisher<- read_excel("Sampling_protocol_fisher_TableToExcel.xlsx")
lynx<- read_excel("Sampling_protocol_lynx_protectionzone_TableToExcel.xlsx")
moose<- read_excel("Sampling_protocol_moose_TableToExcel.xlsx")
porcupine<- read_excel("Sampling_protocol_porcupine_TableToExcel.xlsx")
raccoon<- read_excel("Sampling_protocol_raccoon_TableToExcel.xlsx")
redfox<- read_excel("Sampling_protocol_redfox_TableToExcel.xlsx")
snowshoehare<- read_excel("Sampling_protocol_snowshoehare_TableToExcel.xlsx")
squirrel<- read_excel("Sampling_protocol_squirrel_TableToExcel.xlsx")
stweasel<- read_excel("Sampling_protocol_STweasel_TableToExcel.xlsx")

marten<-as.data.frame(marten)
bear<-as.data.frame(bear)
bobcat<-as.data.frame(bobcat)
coyote<-as.data.frame(coyote)
deer<-as.data.frame(deer)
fisher<-as.data.frame(fisher)
lynx<-as.data.frame(lynx)
moose<-as.data.frame(moose)
porcupine<-as.data.frame(porcupine)
redfox<-as.data.frame(redfox)
snowshoehare<-as.data.frame(snowshoehare)
squirrel<-as.data.frame(squirrel)
stweasel<-as.data.frame(stweasel)


#### Change column names so that when we merge later we have the species in the name####

names(marten)[names(marten) == "Sampl50"] <- "martenSampl50"
names(marten)[names(marten) == "Sampl25"] <- "martenSampl25"
names(marten)[names(marten) == "Sampl10"] <- "martenSampl10"

names(bear)[names(bear) == "Sampl50"] <- "bearSampl50"
names(bear)[names(bear) == "Sampl25"] <- "bearSampl25"
names(bear)[names(bear) == "Sampl10"] <- "bearSampl10"

names(bobcat)[names(bobcat) == "Sampl50"] <- "bobcatSampl50"
names(bobcat)[names(bobcat) == "Sampl25"] <- "bobcatSampl25"
names(bobcat)[names(bobcat) == "Sampl10"] <- "bobcatSampl10"

names(coyote)[names(coyote) == "Sampl50"] <- "coyoteSampl50"
names(coyote)[names(coyote) == "Sampl25"] <- "coyoteSampl25"
names(coyote)[names(coyote) == "Sampl10"] <- "coyoteSampl10"

names(deer)[names(deer) == "Sampl50"] <- "deerSampl50"
names(deer)[names(deer) == "Sampl25"] <- "deerSampl25"
names(deer)[names(deer) == "Sampl10"] <- "deerSampl10"

names(fisher)[names(fisher) == "Sampl50"] <- "fisherSampl50"
names(fisher)[names(fisher) == "Sampl25"] <- "fisherSampl25"
names(fisher)[names(fisher) == "Sampl10"] <- "fisherSampl10"

names(lynx)[names(lynx) == "Sampl50"] <- "lynxSampl50"
names(lynx)[names(lynx) == "Sampl25"] <- "lynxSampl25"
names(lynx)[names(lynx) == "Sampl10"] <- "lynxSampl10"

names(moose)[names(moose) == "Sampl50"] <- "mooseSampl50"
names(moose)[names(moose) == "Sampl25"] <- "mooseSampl25"
names(moose)[names(moose) == "Sampl10"] <- "mooseSampl10"

names(porcupine)[names(porcupine) == "Sampl50"] <- "porcupineSampl50"
names(porcupine)[names(porcupine) == "Sampl25"] <- "porcupineSampl25"
names(porcupine)[names(porcupine) == "Sampl10"] <- "porcupineSampl10"

names(raccoon)[names(raccoon) == "Sampl50"] <- "raccoonSampl50"
names(raccoon)[names(raccoon) == "Sampl25"] <- "raccoonSampl25"
names(raccoon)[names(raccoon) == "Sampl10"] <- "raccoonSampl10"

names(redfox)[names(redfox) == "Sampl50"] <- "redfoxSampl50"
names(redfox)[names(redfox) == "Sampl25"] <- "redfoxSampl25"
names(redfox)[names(redfox) == "Sampl10"] <- "redfoxSampl10"

names(snowshoehare)[names(snowshoehare) == "Sampl50"] <- "snowshoehareSampl50"
names(snowshoehare)[names(snowshoehare) == "Sampl25"] <- "snowshoehareSampl25"
names(snowshoehare)[names(snowshoehare) == "Sampl10"] <- "snowshoehareSampl10"

names(squirrel)[names(squirrel) == "Sampl50"] <- "squirrelSampl50"
names(squirrel)[names(squirrel) == "Sampl25"] <- "squirrelSampl25"
names(squirrel)[names(squirrel) == "Sampl10"] <- "squirrelSampl10"

names(stweasel)[names(stweasel) == "Sampl50"] <- "stweaselSampl50"
names(stweasel)[names(stweasel) == "Sampl25"] <- "stweaselSampl25"
names(stweasel)[names(stweasel) == "Sampl10"] <- "stweaselSampl10"


#### First remove areas where marten occupancy is below 0.2 ####
marten<-subset(marten, marten$psiavg >= 0.2)


#### ** ####

#### Subset Marten Low, Medium, and High effort at 50% sampling effort ####

martenlow<- subset(marten, martenSampl50 <= 5)

martenmed<- subset(marten, martenSampl50 >5 & martenSampl50 <= 8)

martenhigh<- subset(marten, martenSampl50 > 8 & martenSampl50 <= 12)


#### ** ####
#### Low effort - Marten 50% change detection ####
#### ** ####

#### Marten and Bear ####
martenbear<-merge(martenlow, bear[,c("bearSampl50", "bearSampl25", "bearSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenbear$marten50_bear10<-ifelse(martenbear$bearSampl10 <= 5, "in", "out")
martenbear$marten50_bear25<-ifelse(martenbear$bearSampl25 <= 5, "in", "out")
martenbear$marten50_bear50<-ifelse(martenbear$bearSampl50 <= 5, "in", "out")

martenbear$marten50_bear10<-as.factor(martenbear$marten50_bear10)
martenbear$marten50_bear25<-as.factor(martenbear$marten50_bear25)
martenbear$marten50_bear50<-as.factor(martenbear$marten50_bear50)


summary(martenbear)
# bear 10% - 0/320 in
# bear 25% - 320/320 in
# bear 50% - 320/320 in


#### Marten and Bobcat ####
martenbobcat<-merge(martenlow, bobcat[,c("bobcatSampl50", "bobcatSampl25", "bobcatSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenbobcat$marten50_bobcat10<-ifelse(martenbobcat$bobcatSampl10 <= 5, "in", "out")
martenbobcat$marten50_bobcat25<-ifelse(martenbobcat$bobcatSampl25 <= 5, "in", "out")
martenbobcat$marten50_bobcat50<-ifelse(martenbobcat$bobcatSampl50 <= 5, "in", "out")

martenbobcat$marten50_bobcat10<-as.factor(martenbobcat$marten50_bobcat10)
martenbobcat$marten50_bobcat25<-as.factor(martenbobcat$marten50_bobcat25)
martenbobcat$marten50_bobcat50<-as.factor(martenbobcat$marten50_bobcat50)


summary(martenbobcat)
# bobcat 10% - 0/320 in
# bobcat 25% - 0/320 in
# bobcat 50% - 0/320 in



#### Marten and Coyote ####
martencoyote<-merge(martenlow, coyote[,c("coyoteSampl50", "coyoteSampl25", "coyoteSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martencoyote$marten50_coyote10<-ifelse(martencoyote$coyoteSampl10 <= 5, "in", "out")
martencoyote$marten50_coyote25<-ifelse(martencoyote$coyoteSampl25 <= 5, "in", "out")
martencoyote$marten50_coyote50<-ifelse(martencoyote$coyoteSampl50 <= 5, "in", "out")

martencoyote$marten50_coyote10<-as.factor(martencoyote$marten50_coyote10)
martencoyote$marten50_coyote25<-as.factor(martencoyote$marten50_coyote25)
martencoyote$marten50_coyote50<-as.factor(martencoyote$marten50_coyote50)


summary(martencoyote)
# coyote 10% - 0/320 in
# coyote 25% - 0/320 in
# coyote 50% - 125/320 in



#### Marten and Deer ####
martendeer<-merge(martenlow, deer[,c("deerSampl50", "deerSampl25", "deerSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martendeer$marten50_deer10<-ifelse(martendeer$deerSampl10 <= 5, "in", "out")
martendeer$marten50_deer25<-ifelse(martendeer$deerSampl25 <= 5, "in", "out")
martendeer$marten50_deer50<-ifelse(martendeer$deerSampl50 <= 5, "in", "out")

martendeer$marten50_deer10<-as.factor(martendeer$marten50_deer10)
martendeer$marten50_deer25<-as.factor(martendeer$marten50_deer25)
martendeer$marten50_deer50<-as.factor(martendeer$marten50_deer50)


summary(martendeer)
# deer 10% - 0/320 in
# deer 25% - 144/320 in
# deer 50% - 313/320 in



#### Marten and Fisher ####
martenfisher<-merge(martenlow, fisher[,c("fisherSampl50", "fisherSampl25", "fisherSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenfisher$marten50_fisher10<-ifelse(martenfisher$fisherSampl10 <= 5, "in", "out")
martenfisher$marten50_fisher25<-ifelse(martenfisher$fisherSampl25 <= 5, "in", "out")
martenfisher$marten50_fisher50<-ifelse(martenfisher$fisherSampl50 <= 5, "in", "out")

martenfisher$marten50_fisher10<-as.factor(martenfisher$marten50_fisher10)
martenfisher$marten50_fisher25<-as.factor(martenfisher$marten50_fisher25)
martenfisher$marten50_fisher50<-as.factor(martenfisher$marten50_fisher50)


summary(martenfisher)
# fisher 10% - 0/320 in
# fisher 25% - 0/320 in
# fisher 50% - 320/320 in


#### Marten and Lynx ####
martenlynx<-merge(martenlow, lynx[,c("lynxSampl50", "lynxSampl25", "lynxSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenlynx$marten50_lynx10<-ifelse(martenlynx$lynxSampl10 <= 5, "in", "out")
martenlynx$marten50_lynx25<-ifelse(martenlynx$lynxSampl25 <= 5, "in", "out")
martenlynx$marten50_lynx50<-ifelse(martenlynx$lynxSampl50 <= 5, "in", "out")

martenlynx$marten50_lynx10<-as.factor(martenlynx$marten50_lynx10)
martenlynx$marten50_lynx25<-as.factor(martenlynx$marten50_lynx25)
martenlynx$marten50_lynx50<-as.factor(martenlynx$marten50_lynx50)


summary(martenlynx)
# lynx 10% - 0/191 in
# lynx 25% - 0/191 in
# lynx 50% - 0/191 in


#### Marten and Moose ####
martenmoose<-merge(martenlow, moose[,c("mooseSampl50", "mooseSampl25", "mooseSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenmoose$marten50_moose10<-ifelse(martenmoose$mooseSampl10 <= 5, "in", "out")
martenmoose$marten50_moose25<-ifelse(martenmoose$mooseSampl25 <= 5, "in", "out")
martenmoose$marten50_moose50<-ifelse(martenmoose$mooseSampl50 <= 5, "in", "out")

martenmoose$marten50_moose10<-as.factor(martenmoose$marten50_moose10)
martenmoose$marten50_moose25<-as.factor(martenmoose$marten50_moose25)
martenmoose$marten50_moose50<-as.factor(martenmoose$marten50_moose50)


summary(martenmoose)
# moose 10% - 0/320 in
# moose 25% - 0/320 in
# moose 50% - 0/320 in



#### Marten and Porcupine ####
martenporcupine<-merge(martenlow, porcupine[,c("porcupineSampl50", "porcupineSampl25", "porcupineSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenporcupine$marten50_porcupine10<-ifelse(martenporcupine$porcupineSampl10 <= 5, "in", "out")
martenporcupine$marten50_porcupine25<-ifelse(martenporcupine$porcupineSampl25 <= 5, "in", "out")
martenporcupine$marten50_porcupine50<-ifelse(martenporcupine$porcupineSampl50 <= 5, "in", "out")

martenporcupine$marten50_porcupine10<-as.factor(martenporcupine$marten50_porcupine10)
martenporcupine$marten50_porcupine25<-as.factor(martenporcupine$marten50_porcupine25)
martenporcupine$marten50_porcupine50<-as.factor(martenporcupine$marten50_porcupine50)


summary(martenporcupine)
# porcupine 10% - 0/320 in
# porcupine 25% - 0/320 in
# porcupine 50% - 0/320 in


#### Marten and Raccoon ####
martenraccoon<-merge(martenlow, raccoon[,c("raccoonSampl50", "raccoonSampl25", "raccoonSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenraccoon$marten50_raccoon10<-ifelse(martenraccoon$raccoonSampl10 <= 5, "in", "out")
martenraccoon$marten50_raccoon25<-ifelse(martenraccoon$raccoonSampl25 <= 5, "in", "out")
martenraccoon$marten50_raccoon50<-ifelse(martenraccoon$raccoonSampl50 <= 5, "in", "out")

martenraccoon$marten50_raccoon10<-as.factor(martenraccoon$marten50_raccoon10)
martenraccoon$marten50_raccoon25<-as.factor(martenraccoon$marten50_raccoon25)
martenraccoon$marten50_raccoon50<-as.factor(martenraccoon$marten50_raccoon50)


summary(martenraccoon)
# raccoon 10% - 0/320 in
# raccoon 25% - 0/320 in
# raccoon 50% - 3/320 in



#### Marten and Red Fox ####
martenredfox<-merge(martenlow, redfox[,c("redfoxSampl50", "redfoxSampl25", "redfoxSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenredfox$marten50_redfox10<-ifelse(martenredfox$redfoxSampl10 <= 5, "in", "out")
martenredfox$marten50_redfox25<-ifelse(martenredfox$redfoxSampl25 <= 5, "in", "out")
martenredfox$marten50_redfox50<-ifelse(martenredfox$redfoxSampl50 <= 5, "in", "out")

martenredfox$marten50_redfox10<-as.factor(martenredfox$marten50_redfox10)
martenredfox$marten50_redfox25<-as.factor(martenredfox$marten50_redfox25)
martenredfox$marten50_redfox50<-as.factor(martenredfox$marten50_redfox50)


summary(martenredfox)
# redfox 10% - 0/320 in
# redfox 25% - 0/320 in
# redfox 50% - 0/320 in



#### Marten and Snowshoe hare ####
martensnowshoehare<-merge(martenlow, snowshoehare[,c("snowshoehareSampl50", "snowshoehareSampl25", "snowshoehareSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martensnowshoehare$marten50_snowshoehare10<-ifelse(martensnowshoehare$snowshoehareSampl10 <= 5, "in", "out")
martensnowshoehare$marten50_snowshoehare25<-ifelse(martensnowshoehare$snowshoehareSampl25 <= 5, "in", "out")
martensnowshoehare$marten50_snowshoehare50<-ifelse(martensnowshoehare$snowshoehareSampl50 <= 5, "in", "out")

martensnowshoehare$marten50_snowshoehare10<-as.factor(martensnowshoehare$marten50_snowshoehare10)
martensnowshoehare$marten50_snowshoehare25<-as.factor(martensnowshoehare$marten50_snowshoehare25)
martensnowshoehare$marten50_snowshoehare50<-as.factor(martensnowshoehare$marten50_snowshoehare50)


summary(martensnowshoehare)
# snowshoehare 10% - 0/320 in
# snowshoehare 25% - 77/320 in
# snowshoehare 50% - 320/320 in


#### Marten and Squirrel ####
martensquirrel<-merge(martenlow, squirrel[,c("squirrelSampl50", "squirrelSampl25", "squirrelSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martensquirrel$marten50_squirrel10<-ifelse(martensquirrel$squirrelSampl10 <= 5, "in", "out")
martensquirrel$marten50_squirrel25<-ifelse(martensquirrel$squirrelSampl25 <= 5, "in", "out")
martensquirrel$marten50_squirrel50<-ifelse(martensquirrel$squirrelSampl50 <= 5, "in", "out")

martensquirrel$marten50_squirrel10<-as.factor(martensquirrel$marten50_squirrel10)
martensquirrel$marten50_squirrel25<-as.factor(martensquirrel$marten50_squirrel25)
martensquirrel$marten50_squirrel50<-as.factor(martensquirrel$marten50_squirrel50)


summary(martensquirrel)
# squirrel 10% - 0/320 in
# squirrel 25% - 320/320 in
# squirrel 50% - 320/320 in



#### Marten and Short-tailed weasel ####
martenstweasel<-merge(martenlow, stweasel[,c("stweaselSampl50", "stweaselSampl25", "stweaselSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenstweasel$marten50_stweasel10<-ifelse(martenstweasel$stweaselSampl10 <= 5, "in", "out")
martenstweasel$marten50_stweasel25<-ifelse(martenstweasel$stweaselSampl25 <= 5, "in", "out")
martenstweasel$marten50_stweasel50<-ifelse(martenstweasel$stweaselSampl50 <= 5, "in", "out")

martenstweasel$marten50_stweasel10<-as.factor(martenstweasel$marten50_stweasel10)
martenstweasel$marten50_stweasel25<-as.factor(martenstweasel$marten50_stweasel25)
martenstweasel$marten50_stweasel50<-as.factor(martenstweasel$marten50_stweasel50)


summary(martenstweasel)
# stweasel 10% - 0/320 in
# stweasel 25% - 0/320 in
# stweasel 50% - 0/320 in



#### ** ####
#### Medium effort - Marten 50% change detection ####
#### ** ####

#### Marten and Bear ####
martenbear<-merge(martenmed, bear[,c("bearSampl50", "bearSampl25", "bearSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenbear$marten50_bear10<-ifelse(martenbear$bearSampl10 <= 8, "in", "out")
martenbear$marten50_bear25<-ifelse(martenbear$bearSampl25 <= 8, "in", "out")
martenbear$marten50_bear50<-ifelse(martenbear$bearSampl50 <= 8, "in", "out")

martenbear$marten50_bear10<-as.factor(martenbear$marten50_bear10)
martenbear$marten50_bear25<-as.factor(martenbear$marten50_bear25)
martenbear$marten50_bear50<-as.factor(martenbear$marten50_bear50)


summary(martenbear)
# bear 10% - 0/341 in
# bear 25% - 341/341 in
# bear 50% - 341/341 in


#### Marten and Bobcat ####
martenbobcat<-merge(martenmed, bobcat[,c("bobcatSampl50", "bobcatSampl25", "bobcatSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenbobcat$marten50_bobcat10<-ifelse(martenbobcat$bobcatSampl10 <= 8, "in", "out")
martenbobcat$marten50_bobcat25<-ifelse(martenbobcat$bobcatSampl25 <= 8, "in", "out")
martenbobcat$marten50_bobcat50<-ifelse(martenbobcat$bobcatSampl50 <= 8, "in", "out")

martenbobcat$marten50_bobcat10<-as.factor(martenbobcat$marten50_bobcat10)
martenbobcat$marten50_bobcat25<-as.factor(martenbobcat$marten50_bobcat25)
martenbobcat$marten50_bobcat50<-as.factor(martenbobcat$marten50_bobcat50)


summary(martenbobcat)
# bobcat 10% - 0/341 in
# bobcat 25% - 0/341 in
# bobcat 50% - 0/341 in



#### Marten and Coyote ####
martencoyote<-merge(martenmed, coyote[,c("coyoteSampl50", "coyoteSampl25", "coyoteSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martencoyote$marten50_coyote10<-ifelse(martencoyote$coyoteSampl10 <= 8, "in", "out")
martencoyote$marten50_coyote25<-ifelse(martencoyote$coyoteSampl25 <= 8, "in", "out")
martencoyote$marten50_coyote50<-ifelse(martencoyote$coyoteSampl50 <= 8, "in", "out")

martencoyote$marten50_coyote10<-as.factor(martencoyote$marten50_coyote10)
martencoyote$marten50_coyote25<-as.factor(martencoyote$marten50_coyote25)
martencoyote$marten50_coyote50<-as.factor(martencoyote$marten50_coyote50)


summary(martencoyote)
# coyote 10% - 0/341 in
# coyote 25% - 0/341 in
# coyote 50% - 183/341 in



#### Marten and Deer ####
martendeer<-merge(martenmed, deer[,c("deerSampl50", "deerSampl25", "deerSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martendeer$marten50_deer10<-ifelse(martendeer$deerSampl10 <= 8, "in", "out")
martendeer$marten50_deer25<-ifelse(martendeer$deerSampl25 <= 8, "in", "out")
martendeer$marten50_deer50<-ifelse(martendeer$deerSampl50 <= 8, "in", "out")

martendeer$marten50_deer10<-as.factor(martendeer$marten50_deer10)
martendeer$marten50_deer25<-as.factor(martendeer$marten50_deer25)
martendeer$marten50_deer50<-as.factor(martendeer$marten50_deer50)


summary(martendeer)
# deer 10% - 0/341 in
# deer 25% - 233/341 in
# deer 50% - 341/341 in



#### Marten and Fisher ####
martenfisher<-merge(martenmed, fisher[,c("fisherSampl50", "fisherSampl25", "fisherSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenfisher$marten50_fisher10<-ifelse(martenfisher$fisherSampl10 <= 8, "in", "out")
martenfisher$marten50_fisher25<-ifelse(martenfisher$fisherSampl25 <= 8, "in", "out")
martenfisher$marten50_fisher50<-ifelse(martenfisher$fisherSampl50 <= 8, "in", "out")

martenfisher$marten50_fisher10<-as.factor(martenfisher$marten50_fisher10)
martenfisher$marten50_fisher25<-as.factor(martenfisher$marten50_fisher25)
martenfisher$marten50_fisher50<-as.factor(martenfisher$marten50_fisher50)


summary(martenfisher)
# fisher 10% - 0/341 in
# fisher 25% - 76/341 in
# fisher 50% - 341/341 in


#### Marten and Lynx ####
martenlynx<-merge(martenmed, lynx[,c("lynxSampl50", "lynxSampl25", "lynxSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenlynx$marten50_lynx10<-ifelse(martenlynx$lynxSampl10 <= 8, "in", "out")
martenlynx$marten50_lynx25<-ifelse(martenlynx$lynxSampl25 <= 8, "in", "out")
martenlynx$marten50_lynx50<-ifelse(martenlynx$lynxSampl50 <= 8, "in", "out")

martenlynx$marten50_lynx10<-as.factor(martenlynx$marten50_lynx10)
martenlynx$marten50_lynx25<-as.factor(martenlynx$marten50_lynx25)
martenlynx$marten50_lynx50<-as.factor(martenlynx$marten50_lynx50)


summary(martenlynx)
# lynx 10% - 0/294 in
# lynx 25% - 0/294 in
# lynx 50% - 0/294 in


#### Marten and Moose ####
martenmoose<-merge(martenmed, moose[,c("mooseSampl50", "mooseSampl25", "mooseSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenmoose$marten50_moose10<-ifelse(martenmoose$mooseSampl10 <= 8, "in", "out")
martenmoose$marten50_moose25<-ifelse(martenmoose$mooseSampl25 <= 8, "in", "out")
martenmoose$marten50_moose50<-ifelse(martenmoose$mooseSampl50 <= 8, "in", "out")

martenmoose$marten50_moose10<-as.factor(martenmoose$marten50_moose10)
martenmoose$marten50_moose25<-as.factor(martenmoose$marten50_moose25)
martenmoose$marten50_moose50<-as.factor(martenmoose$marten50_moose50)


summary(martenmoose)
# moose 10% - 0/341 in
# moose 25% - 0/341 in
# moose 50% - 0/341 in



#### Marten and Porcupine ####
martenporcupine<-merge(martenmed, porcupine[,c("porcupineSampl50", "porcupineSampl25", "porcupineSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenporcupine$marten50_porcupine10<-ifelse(martenporcupine$porcupineSampl10 <= 8, "in", "out")
martenporcupine$marten50_porcupine25<-ifelse(martenporcupine$porcupineSampl25 <= 8, "in", "out")
martenporcupine$marten50_porcupine50<-ifelse(martenporcupine$porcupineSampl50 <= 8, "in", "out")

martenporcupine$marten50_porcupine10<-as.factor(martenporcupine$marten50_porcupine10)
martenporcupine$marten50_porcupine25<-as.factor(martenporcupine$marten50_porcupine25)
martenporcupine$marten50_porcupine50<-as.factor(martenporcupine$marten50_porcupine50)


summary(martenporcupine)
# porcupine 10% - 0/341 in
# porcupine 25% - 0/341 in
# porcupine 50% - 0/341 in


#### Marten and Raccoon ####
martenraccoon<-merge(martenmed, raccoon[,c("raccoonSampl50", "raccoonSampl25", "raccoonSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenraccoon$marten50_raccoon10<-ifelse(martenraccoon$raccoonSampl10 <= 8, "in", "out")
martenraccoon$marten50_raccoon25<-ifelse(martenraccoon$raccoonSampl25 <= 8, "in", "out")
martenraccoon$marten50_raccoon50<-ifelse(martenraccoon$raccoonSampl50 <= 8, "in", "out")

martenraccoon$marten50_raccoon10<-as.factor(martenraccoon$marten50_raccoon10)
martenraccoon$marten50_raccoon25<-as.factor(martenraccoon$marten50_raccoon25)
martenraccoon$marten50_raccoon50<-as.factor(martenraccoon$marten50_raccoon50)


summary(martenraccoon)
# raccoon 10% - 0/341 in
# raccoon 25% - 0/341 in
# raccoon 50% - 1/341 in



#### Marten and Red Fox ####
martenredfox<-merge(martenmed, redfox[,c("redfoxSampl50", "redfoxSampl25", "redfoxSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenredfox$marten50_redfox10<-ifelse(martenredfox$redfoxSampl10 <= 8, "in", "out")
martenredfox$marten50_redfox25<-ifelse(martenredfox$redfoxSampl25 <= 8, "in", "out")
martenredfox$marten50_redfox50<-ifelse(martenredfox$redfoxSampl50 <= 8, "in", "out")

martenredfox$marten50_redfox10<-as.factor(martenredfox$marten50_redfox10)
martenredfox$marten50_redfox25<-as.factor(martenredfox$marten50_redfox25)
martenredfox$marten50_redfox50<-as.factor(martenredfox$marten50_redfox50)


summary(martenredfox)
# redfox 10% - 0/341 in
# redfox 25% - 0/341 in
# redfox 50% - 0/341 in



#### Marten and Snowshoe hare ####
martensnowshoehare<-merge(martenmed, snowshoehare[,c("snowshoehareSampl50", "snowshoehareSampl25", "snowshoehareSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martensnowshoehare$marten50_snowshoehare10<-ifelse(martensnowshoehare$snowshoehareSampl10 <= 8, "in", "out")
martensnowshoehare$marten50_snowshoehare25<-ifelse(martensnowshoehare$snowshoehareSampl25 <= 8, "in", "out")
martensnowshoehare$marten50_snowshoehare50<-ifelse(martensnowshoehare$snowshoehareSampl50 <= 8, "in", "out")

martensnowshoehare$marten50_snowshoehare10<-as.factor(martensnowshoehare$marten50_snowshoehare10)
martensnowshoehare$marten50_snowshoehare25<-as.factor(martensnowshoehare$marten50_snowshoehare25)
martensnowshoehare$marten50_snowshoehare50<-as.factor(martensnowshoehare$marten50_snowshoehare50)


summary(martensnowshoehare)
# snowshoehare 10% - 0/341 in
# snowshoehare 25% - 226/341 in
# snowshoehare 50% - 341/341 in


#### Marten and Squirrel ####
martensquirrel<-merge(martenmed, squirrel[,c("squirrelSampl50", "squirrelSampl25", "squirrelSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martensquirrel$marten50_squirrel10<-ifelse(martensquirrel$squirrelSampl10 <= 8, "in", "out")
martensquirrel$marten50_squirrel25<-ifelse(martensquirrel$squirrelSampl25 <= 8, "in", "out")
martensquirrel$marten50_squirrel50<-ifelse(martensquirrel$squirrelSampl50 <= 8, "in", "out")

martensquirrel$marten50_squirrel10<-as.factor(martensquirrel$marten50_squirrel10)
martensquirrel$marten50_squirrel25<-as.factor(martensquirrel$marten50_squirrel25)
martensquirrel$marten50_squirrel50<-as.factor(martensquirrel$marten50_squirrel50)


summary(martensquirrel)
# squirrel 10% - 186/341 in
# squirrel 25% - 341/341 in
# squirrel 50% - 341/341 in


#### Marten and Short-tailed weasel ####
martenstweasel<-merge(martenmed, stweasel[,c("stweaselSampl50", "stweaselSampl25", "stweaselSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenstweasel$marten50_stweasel10<-ifelse(martenstweasel$stweaselSampl10 <= 8, "in", "out")
martenstweasel$marten50_stweasel25<-ifelse(martenstweasel$stweaselSampl25 <= 8, "in", "out")
martenstweasel$marten50_stweasel50<-ifelse(martenstweasel$stweaselSampl50 <= 8, "in", "out")

martenstweasel$marten50_stweasel10<-as.factor(martenstweasel$marten50_stweasel10)
martenstweasel$marten50_stweasel25<-as.factor(martenstweasel$marten50_stweasel25)
martenstweasel$marten50_stweasel50<-as.factor(martenstweasel$marten50_stweasel50)


summary(martenstweasel)
# stweasel 10% - 0/317 in
# stweasel 25% - 0/317 in
# stweasel 50% - 225/317 in


#### ** ####
#### High effort - Marten 50% change detection ####
#### ** ####

#### Marten and Bear ####
martenbear<-merge(martenhigh, bear[,c("bearSampl50", "bearSampl25", "bearSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenbear$marten50_bear10<-ifelse(martenbear$bearSampl10 <= 12, "in", "out")
martenbear$marten50_bear25<-ifelse(martenbear$bearSampl25 <= 12, "in", "out")
martenbear$marten50_bear50<-ifelse(martenbear$bearSampl50 <= 12, "in", "out")

martenbear$marten50_bear10<-as.factor(martenbear$marten50_bear10)
martenbear$marten50_bear25<-as.factor(martenbear$marten50_bear25)
martenbear$marten50_bear50<-as.factor(martenbear$marten50_bear50)


summary(martenbear)
# bear 10% - 66/69 in
# bear 25% - 69/69 in
# bear 50% - 69/69 in


#### Marten and Bobcat ####
martenbobcat<-merge(martenhigh, bobcat[,c("bobcatSampl50", "bobcatSampl25", "bobcatSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenbobcat$marten50_bobcat10<-ifelse(martenbobcat$bobcatSampl10 <= 12, "in", "out")
martenbobcat$marten50_bobcat25<-ifelse(martenbobcat$bobcatSampl25 <= 12, "in", "out")
martenbobcat$marten50_bobcat50<-ifelse(martenbobcat$bobcatSampl50 <= 12, "in", "out")

martenbobcat$marten50_bobcat10<-as.factor(martenbobcat$marten50_bobcat10)
martenbobcat$marten50_bobcat25<-as.factor(martenbobcat$marten50_bobcat25)
martenbobcat$marten50_bobcat50<-as.factor(martenbobcat$marten50_bobcat50)


summary(martenbobcat)
# bobcat 10% - 0/69 in
# bobcat 25% - 0/69 in
# bobcat 50% - 0/69 in



#### Marten and Coyote ####
martencoyote<-merge(martenhigh, coyote[,c("coyoteSampl50", "coyoteSampl25", "coyoteSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martencoyote$marten50_coyote10<-ifelse(martencoyote$coyoteSampl10 <= 12, "in", "out")
martencoyote$marten50_coyote25<-ifelse(martencoyote$coyoteSampl25 <= 12, "in", "out")
martencoyote$marten50_coyote50<-ifelse(martencoyote$coyoteSampl50 <= 12, "in", "out")

martencoyote$marten50_coyote10<-as.factor(martencoyote$marten50_coyote10)
martencoyote$marten50_coyote25<-as.factor(martencoyote$marten50_coyote25)
martencoyote$marten50_coyote50<-as.factor(martencoyote$marten50_coyote50)


summary(martencoyote)
# coyote 10% - 0/69 in
# coyote 25% - 0/69 in
# coyote 50% - 56/69 in



#### Marten and Deer ####
martendeer<-merge(martenhigh, deer[,c("deerSampl50", "deerSampl25", "deerSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martendeer$marten50_deer10<-ifelse(martendeer$deerSampl10 <= 12, "in", "out")
martendeer$marten50_deer25<-ifelse(martendeer$deerSampl25 <= 12, "in", "out")
martendeer$marten50_deer50<-ifelse(martendeer$deerSampl50 <= 12, "in", "out")

martendeer$marten50_deer10<-as.factor(martendeer$marten50_deer10)
martendeer$marten50_deer25<-as.factor(martendeer$marten50_deer25)
martendeer$marten50_deer50<-as.factor(martendeer$marten50_deer50)


summary(martendeer)
# deer 10% - 0/69 in
# deer 25% - 65/69 in
# deer 50% - 69/69 in



#### Marten and Fisher ####
martenfisher<-merge(martenhigh, fisher[,c("fisherSampl50", "fisherSampl25", "fisherSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenfisher$marten50_fisher10<-ifelse(martenfisher$fisherSampl10 <= 12, "in", "out")
martenfisher$marten50_fisher25<-ifelse(martenfisher$fisherSampl25 <= 12, "in", "out")
martenfisher$marten50_fisher50<-ifelse(martenfisher$fisherSampl50 <= 12, "in", "out")

martenfisher$marten50_fisher10<-as.factor(martenfisher$marten50_fisher10)
martenfisher$marten50_fisher25<-as.factor(martenfisher$marten50_fisher25)
martenfisher$marten50_fisher50<-as.factor(martenfisher$marten50_fisher50)


summary(martenfisher)
# fisher 10% - 0/69 in
# fisher 25% - 64/69 in
# fisher 50% - 69/69 in


#### Marten and Lynx ####
martenlynx<-merge(martenhigh, lynx[,c("lynxSampl50", "lynxSampl25", "lynxSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenlynx$marten50_lynx10<-ifelse(martenlynx$lynxSampl10 <= 12, "in", "out")
martenlynx$marten50_lynx25<-ifelse(martenlynx$lynxSampl25 <= 12, "in", "out")
martenlynx$marten50_lynx50<-ifelse(martenlynx$lynxSampl50 <= 12, "in", "out")

martenlynx$marten50_lynx10<-as.factor(martenlynx$marten50_lynx10)
martenlynx$marten50_lynx25<-as.factor(martenlynx$marten50_lynx25)
martenlynx$marten50_lynx50<-as.factor(martenlynx$marten50_lynx50)


summary(martenlynx)
# lynx 10% - 0/67 in
# lynx 25% - 0/67 in
# lynx 50% - 0/67 in


#### Marten and Moose ####
martenmoose<-merge(martenhigh, moose[,c("mooseSampl50", "mooseSampl25", "mooseSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenmoose$marten50_moose10<-ifelse(martenmoose$mooseSampl10 <= 12, "in", "out")
martenmoose$marten50_moose25<-ifelse(martenmoose$mooseSampl25 <= 12, "in", "out")
martenmoose$marten50_moose50<-ifelse(martenmoose$mooseSampl50 <= 12, "in", "out")

martenmoose$marten50_moose10<-as.factor(martenmoose$marten50_moose10)
martenmoose$marten50_moose25<-as.factor(martenmoose$marten50_moose25)
martenmoose$marten50_moose50<-as.factor(martenmoose$marten50_moose50)


summary(martenmoose)
# moose 10% - 0/69 in
# moose 25% - 0/69 in
# moose 50% - 0/69 in



#### Marten and Porcupine ####
martenporcupine<-merge(martenhigh, porcupine[,c("porcupineSampl50", "porcupineSampl25", "porcupineSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenporcupine$marten50_porcupine10<-ifelse(martenporcupine$porcupineSampl10 <= 12, "in", "out")
martenporcupine$marten50_porcupine25<-ifelse(martenporcupine$porcupineSampl25 <= 12, "in", "out")
martenporcupine$marten50_porcupine50<-ifelse(martenporcupine$porcupineSampl50 <= 12, "in", "out")

martenporcupine$marten50_porcupine10<-as.factor(martenporcupine$marten50_porcupine10)
martenporcupine$marten50_porcupine25<-as.factor(martenporcupine$marten50_porcupine25)
martenporcupine$marten50_porcupine50<-as.factor(martenporcupine$marten50_porcupine50)


summary(martenporcupine)
# porcupine 10% - 0/69 in
# porcupine 25% - 0/69 in
# porcupine 50% - 0/69 in


#### Marten and Raccoon ####
martenraccoon<-merge(martenhigh, raccoon[,c("raccoonSampl50", "raccoonSampl25", "raccoonSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenraccoon$marten50_raccoon10<-ifelse(martenraccoon$raccoonSampl10 <= 12, "in", "out")
martenraccoon$marten50_raccoon25<-ifelse(martenraccoon$raccoonSampl25 <= 12, "in", "out")
martenraccoon$marten50_raccoon50<-ifelse(martenraccoon$raccoonSampl50 <= 12, "in", "out")

martenraccoon$marten50_raccoon10<-as.factor(martenraccoon$marten50_raccoon10)
martenraccoon$marten50_raccoon25<-as.factor(martenraccoon$marten50_raccoon25)
martenraccoon$marten50_raccoon50<-as.factor(martenraccoon$marten50_raccoon50)


summary(martenraccoon)
# raccoon 10% - 0/69 in
# raccoon 25% - 0/69 in
# raccoon 50% - 0/69 in



#### Marten and Red Fox ####
martenredfox<-merge(martenhigh, redfox[,c("redfoxSampl50", "redfoxSampl25", "redfoxSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenredfox$marten50_redfox10<-ifelse(martenredfox$redfoxSampl10 <= 12, "in", "out")
martenredfox$marten50_redfox25<-ifelse(martenredfox$redfoxSampl25 <= 12, "in", "out")
martenredfox$marten50_redfox50<-ifelse(martenredfox$redfoxSampl50 <= 12, "in", "out")

martenredfox$marten50_redfox10<-as.factor(martenredfox$marten50_redfox10)
martenredfox$marten50_redfox25<-as.factor(martenredfox$marten50_redfox25)
martenredfox$marten50_redfox50<-as.factor(martenredfox$marten50_redfox50)


summary(martenredfox)
# redfox 10% - 0/69 in
# redfox 25% - 0/69 in
# redfox 50% - 0/69 in



#### Marten and Snowshoe hare ####
martensnowshoehare<-merge(martenhigh, snowshoehare[,c("snowshoehareSampl50", "snowshoehareSampl25", "snowshoehareSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martensnowshoehare$marten50_snowshoehare10<-ifelse(martensnowshoehare$snowshoehareSampl10 <= 12, "in", "out")
martensnowshoehare$marten50_snowshoehare25<-ifelse(martensnowshoehare$snowshoehareSampl25 <= 12, "in", "out")
martensnowshoehare$marten50_snowshoehare50<-ifelse(martensnowshoehare$snowshoehareSampl50 <= 12, "in", "out")

martensnowshoehare$marten50_snowshoehare10<-as.factor(martensnowshoehare$marten50_snowshoehare10)
martensnowshoehare$marten50_snowshoehare25<-as.factor(martensnowshoehare$marten50_snowshoehare25)
martensnowshoehare$marten50_snowshoehare50<-as.factor(martensnowshoehare$marten50_snowshoehare50)


summary(martensnowshoehare)
# snowshoehare 10% - 0/69 in
# snowshoehare 25% - 68/69 in
# snowshoehare 50% - 69/69 in


#### Marten and Squirrel ####
martensquirrel<-merge(martenhigh, squirrel[,c("squirrelSampl50", "squirrelSampl25", "squirrelSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martensquirrel$marten50_squirrel10<-ifelse(martensquirrel$squirrelSampl10 <= 12, "in", "out")
martensquirrel$marten50_squirrel25<-ifelse(martensquirrel$squirrelSampl25 <= 12, "in", "out")
martensquirrel$marten50_squirrel50<-ifelse(martensquirrel$squirrelSampl50 <= 12, "in", "out")

martensquirrel$marten50_squirrel10<-as.factor(martensquirrel$marten50_squirrel10)
martensquirrel$marten50_squirrel25<-as.factor(martensquirrel$marten50_squirrel25)
martensquirrel$marten50_squirrel50<-as.factor(martensquirrel$marten50_squirrel50)


summary(martensquirrel)
# squirrel 10% - 69/69 in
# squirrel 25% - 69/69 in
# squirrel 50% - 69/69 in


#### Marten and Short-tailed weasel ####
martenstweasel<-merge(martenhigh, stweasel[,c("stweaselSampl50", "stweaselSampl25", "stweaselSampl10", "TOWN")], by="TOWN", all.x = TRUE)

martenstweasel$marten50_stweasel10<-ifelse(martenstweasel$stweaselSampl10 <= 12, "in", "out")
martenstweasel$marten50_stweasel25<-ifelse(martenstweasel$stweaselSampl25 <= 12, "in", "out")
martenstweasel$marten50_stweasel50<-ifelse(martenstweasel$stweaselSampl50 <= 12, "in", "out")

martenstweasel$marten50_stweasel10<-as.factor(martenstweasel$marten50_stweasel10)
martenstweasel$marten50_stweasel25<-as.factor(martenstweasel$marten50_stweasel25)
martenstweasel$marten50_stweasel50<-as.factor(martenstweasel$marten50_stweasel50)


summary(martenstweasel)
# stweasel 10% - 0/69 in
# stweasel 25% - 0/69 in
# stweasel 50% - 69/69 in